# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_REORIENT_LR_CSH_METADATA = Metadata(
    id="44b9d6ba4983462289bb74a35e46ca2bc4fb3a6c.boutiques",
    name="mri_reorient_LR.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriReorientLrCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_reorient_lr_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reoriented_vol: OutputPathType
    """Reoriented volume"""


def mri_reorient_lr_csh(
    input_vol: InputPathType,
    output_vol: str,
    display_result: bool = False,
    clean_files: bool = False,
    output_registration: bool = False,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> MriReorientLrCshOutputs:
    """
    A script to reorient MRI volumes from left-right orientation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_vol: Input file to be reoriented.
        output_vol: Reoriented input file.
        display_result: Display registration result using FreeView.
        clean_files: Delete all auxiliary and registration files.
        output_registration: Write out the registration file that is applied to\
            the reoriented input file (fslmat or lta).
        version: Print version and exit.
        help_: Print help and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriReorientLrCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_REORIENT_LR_CSH_METADATA)
    cargs = []
    cargs.append("mri_reorient_LR")
    cargs.extend([
        "--i",
        execution.input_file(input_vol)
    ])
    cargs.extend([
        "--o",
        output_vol
    ])
    if display_result:
        cargs.append("--disp")
    if clean_files:
        cargs.append("--clean")
    if output_registration:
        cargs.append("--outreg")
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    ret = MriReorientLrCshOutputs(
        root=execution.output_file("."),
        reoriented_vol=execution.output_file(output_vol),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_REORIENT_LR_CSH_METADATA",
    "MriReorientLrCshOutputs",
    "mri_reorient_lr_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANATOMI_CUTS_UTILS_METADATA = Metadata(
    id="7198fe86c99847a1acd99691b128d75fcca8f4b4.boutiques",
    name="anatomiCutsUtils",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class AnatomiCutsUtilsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `anatomi_cuts_utils(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def anatomi_cuts_utils(
    modules: list[str] | None = None,
    runner: Runner | None = None,
) -> AnatomiCutsUtilsOutputs:
    """
    A tool for anatomical segmentation using graph-based methods.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        modules: Specify the modules to import for processing. Ensure necessary\
            modules like 'graph_tools' are installed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnatomiCutsUtilsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANATOMI_CUTS_UTILS_METADATA)
    cargs = []
    cargs.append("anatomiCutsUtils")
    if modules is not None:
        cargs.extend(modules)
    ret = AnatomiCutsUtilsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANATOMI_CUTS_UTILS_METADATA",
    "AnatomiCutsUtilsOutputs",
    "anatomi_cuts_utils",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_MATCH_METADATA = Metadata(
    id="7d679c04784ea9862b5def825b069decfde8f8d4.boutiques",
    name="surface-match",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceMatchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_match(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_match(
    match_surface_file: InputPathType,
    input_surface_file: InputPathType,
    output_surface_name: str,
    runner: Runner | None = None,
) -> SurfaceMatchOutputs:
    """
    Surface match.
    
    The Input Surface File will be transformed so that its coordinate ranges
    (bounding box) match that of the Match Surface File.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        match_surface_file: Match (Reference) Surface.
        input_surface_file: File containing surface that will be transformed.
        output_surface_name: Surface File after transformation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceMatchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_MATCH_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-match")
    cargs.append(execution.input_file(match_surface_file))
    cargs.append(execution.input_file(input_surface_file))
    cargs.append(output_surface_name)
    ret = SurfaceMatchOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_MATCH_METADATA",
    "SurfaceMatchOutputs",
    "surface_match",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CA_LABEL_METADATA = Metadata(
    id="035eecaadad51f1937fb29e024f977f0c081a952.boutiques",
    name="mri_ca_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCaLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_ca_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_vol: OutputPathType
    """Output labeled volume."""


def mri_ca_label(
    input_volumes: list[InputPathType],
    transform_file: InputPathType,
    gca_file: InputPathType,
    output_volume: str,
    runner: Runner | None = None,
) -> MriCaLabelOutputs:
    """
    MRI cortical annotation labeler using atlas prior (GCA).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volumes: Input MRI volumes.
        transform_file: Transform file for the registration.
        gca_file: GCA file for the atlas.
        output_volume: Output labeled volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCaLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CA_LABEL_METADATA)
    cargs = []
    cargs.append("mri_ca_label")
    cargs.extend([execution.input_file(f) for f in input_volumes])
    cargs.append(execution.input_file(transform_file))
    cargs.append(execution.input_file(gca_file))
    cargs.append(output_volume)
    cargs.append("[OPTIONS]")
    ret = MriCaLabelOutputs(
        root=execution.output_file("."),
        output_vol=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CA_LABEL_METADATA",
    "MriCaLabelOutputs",
    "mri_ca_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AFNITO3_D_METADATA = Metadata(
    id="51230e7f67f1e0eb607573872e1507d7fe45f41a.boutiques",
    name="3dAFNIto3D",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAfnito3DOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_afnito3_d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output 3D file, either in binary or text format"""


def v_3d_afnito3_d(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dAfnito3DOutputs:
    """
    Reads in an AFNI dataset, and writes it out as a 3D file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: AFNI dataset to be converted.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAfnito3DOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AFNITO3_D_METADATA)
    cargs = []
    cargs.append("3dAFNIto3D")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dataset))
    ret = V3dAfnito3DOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("[PREFIX].3D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAfnito3DOutputs",
    "V_3D_AFNITO3_D_METADATA",
    "v_3d_afnito3_d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_EXTRACT_VALUES_METADATA = Metadata(
    id="d71ebcb707ea3a328def8029909fffc5889d56d6.boutiques",
    name="mris_extract_values",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisExtractValuesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_extract_values(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_csv: OutputPathType
    """The CSV file generated by the tool"""


def mris_extract_values(
    surface: InputPathType,
    overlay: InputPathType,
    annotation: InputPathType,
    csvfile: str,
    num_images: float,
    image_files: list[InputPathType],
    runner: Runner | None = None,
) -> MrisExtractValuesOutputs:
    """
    Extracts values from surface, overlay, and annotation files and outputs them to
    a CSV file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Path to the surface file.
        overlay: Path to the overlay file.
        annotation: Path to the annotation file.
        csvfile: Name of the output CSV file.
        num_images: Number of image files to process.
        image_files: List of image files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisExtractValuesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_EXTRACT_VALUES_METADATA)
    cargs = []
    cargs.append("mris_extract_values")
    cargs.extend([
        "-i",
        execution.input_file(surface)
    ])
    cargs.extend([
        "-v",
        execution.input_file(overlay)
    ])
    cargs.extend([
        "-a",
        execution.input_file(annotation)
    ])
    cargs.extend([
        "-o",
        csvfile
    ])
    cargs.extend([
        "-m",
        str(num_images)
    ])
    cargs.extend([
        "--images",
        *[execution.input_file(f) for f in image_files]
    ])
    ret = MrisExtractValuesOutputs(
        root=execution.output_file("."),
        output_csv=execution.output_file(csvfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_EXTRACT_VALUES_METADATA",
    "MrisExtractValuesOutputs",
    "mris_extract_values",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

OPTSEQ2_METADATA = Metadata(
    id="0f4e820b7a3fa22c2de66e83252857cc8c403a78.boutiques",
    name="optseq2",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Optseq2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `optseq2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_schedules: OutputPathType | None
    """Output schedules"""
    output_design_matrices: OutputPathType | None
    """Output FIR design matrices"""
    output_contrast_matrix: OutputPathType | None
    """Output contrast matrix"""
    output_summary: OutputPathType | None
    """Output search summary"""
    output_log: OutputPathType | None
    """Output log file"""
    output_sviter: OutputPathType | None
    """Output per-iteration information"""


def optseq2(
    ntp: float,
    tr: float,
    tprescan: float,
    psdwin: list[float],
    event: list[str] | None = None,
    repvar: str | None = None,
    polyfit: float | None = None,
    tnullmin: float | None = None,
    tnullmax: float | None = None,
    nsearch: float | None = None,
    tsearch: float | None = None,
    first_order_cb: float | None = None,
    ar1: float | None = None,
    penalize: list[float] | None = None,
    evc: list[float] | None = None,
    cmtx: InputPathType | None = None,
    cost: str | None = None,
    sumdelays: bool = False,
    seed: float | None = None,
    nkeep: float | None = None,
    outstem: str | None = None,
    mtxstem: str | None = None,
    cmtxfile: str | None = None,
    summaryfile: str | None = None,
    logfile: str | None = None,
    pctupdate: float | None = None,
    sviterfile: str | None = None,
    instem: str | None = None,
    input_schedule: list[str] | None = None,
    nosearch: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Optseq2Outputs:
    """
    Optseq2 is a tool for automatically scheduling events for rapid-presentation
    event-related (RPER) fMRI experiments.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        ntp: Number of time points to be acquired during the scan.
        tr: Temporal resolution of acquisition in seconds.
        tprescan: Start events t seconds before first acquisition.
        psdwin: Post-stimulus window specifications: minimum PSD, maximum PSD,\
            and optional dPSD.
        event: Event type specification with label, duration, and number of\
            repetitions.
        repvar: Allow number of repetitions of event types to vary by\
            percentage, optionally per event.
        polyfit: Add polynomial regressors as nuisance variables of specified\
            order.
        tnullmin: Minimum duration of null time between stimuli in seconds.
        tnullmax: Maximum duration of null time between stimuli in seconds.
        nsearch: Search over a specified number of iterations for schedules.
        tsearch: Search for schedules over a specified number of hours.
        first_order_cb: Pre-optimize first order counter-balancing.
        ar1: Optimize assuming whitening with AR1 parameter.
        penalize: Penalize for presentations being too close with parameters\
            alpha, T, and dtmin.
        evc: Contrast of event types with weights.
        cmtx: Load contrast from ASCII matrix file.
        cost: Specify cost function and its parameters.
        sumdelays: Sum delays when forming contrast matrix.
        seed: Initialize random number generator with seed value.
        nkeep: Number of best schedules to keep.
        outstem: Output stem for saved schedules.
        mtxstem: Output stem for saved design matrices.
        cmtxfile: File for saving contrast matrix.
        summaryfile: File for saving search summary.
        logfile: File for saving log information.
        pctupdate: Percentage interval after which progress is logged.
        sviterfile: File to save information from each iteration.
        instem: Initialize with input schedules that match instem-RRR.par.
        input_schedule: Input schedule files.
        nosearch: Do not perform search for optimal schedules.
        help_: Print help page.
        version: Print version string.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Optseq2Outputs`).
    """
    if event is not None and (len(event) != 3): 
        raise ValueError(f"Length of 'event' must be 3 but was {len(event)}")
    if ar1 is not None and not (-1 <= ar1 <= 1): 
        raise ValueError(f"'ar1' must be between -1 <= x <= 1 but was {ar1}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(OPTSEQ2_METADATA)
    cargs = []
    cargs.append("optseq2")
    cargs.extend([
        "--ntp",
        str(ntp)
    ])
    cargs.extend([
        "--tr",
        str(tr)
    ])
    cargs.extend([
        "--tprescan",
        str(tprescan)
    ])
    cargs.extend([
        "--psdwin",
        *map(str, psdwin)
    ])
    if event is not None:
        cargs.extend([
            "--ev",
            *event
        ])
    if repvar is not None:
        cargs.extend([
            "--repvar",
            repvar
        ])
    if polyfit is not None:
        cargs.extend([
            "--polyfit",
            str(polyfit)
        ])
    if tnullmin is not None:
        cargs.extend([
            "--tnullmin",
            str(tnullmin)
        ])
    if tnullmax is not None:
        cargs.extend([
            "--tnullmax",
            str(tnullmax)
        ])
    if nsearch is not None:
        cargs.extend([
            "--nsearch",
            str(nsearch)
        ])
    if tsearch is not None:
        cargs.extend([
            "--tsearch",
            str(tsearch)
        ])
    if first_order_cb is not None:
        cargs.extend([
            "--focb",
            str(first_order_cb)
        ])
    if ar1 is not None:
        cargs.extend([
            "--ar1",
            str(ar1)
        ])
    if penalize is not None:
        cargs.extend([
            "--pen",
            *map(str, penalize)
        ])
    if evc is not None:
        cargs.extend([
            "--evc",
            *map(str, evc)
        ])
    if cmtx is not None:
        cargs.extend([
            "--C",
            execution.input_file(cmtx)
        ])
    if cost is not None:
        cargs.extend([
            "--cost",
            cost
        ])
    if sumdelays:
        cargs.append("--sumdelays")
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if nkeep is not None:
        cargs.extend([
            "--nkeep",
            str(nkeep)
        ])
    if outstem is not None:
        cargs.extend([
            "--o",
            outstem
        ])
    if mtxstem is not None:
        cargs.extend([
            "--mtx",
            mtxstem
        ])
    if cmtxfile is not None:
        cargs.extend([
            "--cmtx",
            cmtxfile
        ])
    if summaryfile is not None:
        cargs.extend([
            "--sum",
            summaryfile
        ])
    if logfile is not None:
        cargs.extend([
            "--log",
            logfile
        ])
    if pctupdate is not None:
        cargs.extend([
            "--pctupdate",
            str(pctupdate)
        ])
    if sviterfile is not None:
        cargs.extend([
            "--sviter",
            sviterfile
        ])
    if instem is not None:
        cargs.extend([
            "--i",
            instem
        ])
    if input_schedule is not None:
        cargs.extend([
            "--in",
            *input_schedule
        ])
    if nosearch:
        cargs.append("--nosearch")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = Optseq2Outputs(
        root=execution.output_file("."),
        output_schedules=execution.output_file(outstem + "-RRR.par") if (outstem is not None) else None,
        output_design_matrices=execution.output_file(mtxstem + "_RRR.mat") if (mtxstem is not None) else None,
        output_contrast_matrix=execution.output_file(cmtxfile) if (cmtxfile is not None) else None,
        output_summary=execution.output_file(summaryfile) if (summaryfile is not None) else None,
        output_log=execution.output_file(logfile) if (logfile is not None) else None,
        output_sviter=execution.output_file(sviterfile) if (sviterfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "OPTSEQ2_METADATA",
    "Optseq2Outputs",
    "optseq2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DBUCKET_METADATA = Metadata(
    id="a07bb3d6d6114eb899f05be41e593f262e6cd274.boutiques",
    name="3dbucket",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dbucketOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dbucket(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3dbucket(
    input_files: list[str],
    prefix: str | None = None,
    session: str | None = None,
    glueto: str | None = None,
    aglueto: str | None = None,
    dry: bool = False,
    verbose: bool = False,
    fbuc: bool = False,
    abuc: bool = False,
    runner: Runner | None = None,
) -> V3dbucketOutputs:
    """
    Concatenate sub-bricks from input datasets into one big bucket dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input datasets with optional sub-brick selection.
        prefix: Use 'pname' for the output dataset prefix name.
        session: Use 'dir' for the output dataset session directory.\
            [default='./'=current working directory].
        glueto: Append bricks to the end of the 'fname' dataset.
        aglueto: If fname dataset does not exist, create it (like -prefix).\
            Otherwise append to fname (like -glueto).
        dry: Execute a 'dry run'; only print out what would be done.
        verbose: Print out some verbose output as the program proceeds.
        fbuc: Create a functional bucket.
        abuc: Create an anatomical bucket. If neither of these options is\
            given, the output type is determined from the first input type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dbucketOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DBUCKET_METADATA)
    cargs = []
    cargs.append("3dbucket")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if session is not None:
        cargs.extend([
            "-session",
            session
        ])
    if glueto is not None:
        cargs.extend([
            "-glueto",
            glueto
        ])
    if aglueto is not None:
        cargs.extend([
            "-aglueto",
            aglueto
        ])
    if dry:
        cargs.append("-dry")
    if verbose:
        cargs.append("-verb")
    if fbuc:
        cargs.append("-fbuc")
    if abuc:
        cargs.append("-abuc")
    cargs.extend(input_files)
    ret = V3dbucketOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dbucketOutputs",
    "V_3DBUCKET_METADATA",
    "v_3dbucket",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SFA2FIELDSIGN_METADATA = Metadata(
    id="673483cb133e81114140c357c0715b77a189756a.boutiques",
    name="sfa2fieldsign",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Sfa2fieldsignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sfa2fieldsign(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fsig_bin: OutputPathType
    """Intersection of polar and eccentricity thresholded fieldsigns"""
    eccen_masked: OutputPathType
    """Eccentricity angle (rad) volume masked by fieldsign bin"""
    polar_masked: OutputPathType
    """Polar angle (rad) volume masked by fieldsign bin"""
    eccen_masked_mgh: OutputPathType
    """Masked eccentricity angle sampled on the hemisphere surface"""
    polar_masked_mgh: OutputPathType
    """Masked polar angle sampled on the hemisphere surface"""
    fieldsign_masked_mgh: OutputPathType
    """Masked fieldsign map"""


def sfa2fieldsign(
    sfadir: str,
    register_dat: str,
    threshold: float | None = 2,
    fwhm: float | None = 10,
    proj_frac: float | None = 0.5,
    occip: bool = False,
    patch: str | None = None,
    osd: str | None = None,
    lh: bool = False,
    rh: bool = False,
    runner: Runner | None = None,
) -> Sfa2fieldsignOutputs:
    """
    Computes fieldsign map from sfa-sess output. Masks the angle volumes and samples
    them to the surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        sfadir: Output directory of sfa-sess.
        register_dat: Registration file.
        threshold: Sigthresh threshold (Default: 2).
        fwhm: Full width at half maximum (FWHM) (Default: 10mm).
        proj_frac: Projection fraction (Default: 0.5).
        occip: Use ?h.occip.patch.flat.
        patch: Use specific patch (?)h.patch.
        osd: Directory under SFA to put output (Default: fieldsign).
        lh: Process left hemisphere only.
        rh: Process right hemisphere only.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Sfa2fieldsignOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SFA2FIELDSIGN_METADATA)
    cargs = []
    cargs.append("sfa2fieldsign")
    cargs.extend([
        "--sfa",
        sfadir
    ])
    cargs.extend([
        "--reg",
        register_dat
    ])
    if threshold is not None:
        cargs.extend([
            "--thresh",
            str(threshold)
        ])
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm)
        ])
    if proj_frac is not None:
        cargs.extend([
            "--proj-frac",
            str(proj_frac)
        ])
    if occip:
        cargs.append("--occip")
    if patch is not None:
        cargs.extend([
            "--patch",
            patch
        ])
    if osd is not None:
        cargs.extend([
            "--osd",
            osd
        ])
    if lh:
        cargs.append("--lh")
    if rh:
        cargs.append("--rh")
    ret = Sfa2fieldsignOutputs(
        root=execution.output_file("."),
        fsig_bin=execution.output_file(sfadir + "/[OSD or fieldsign]/fsig.bin.nii"),
        eccen_masked=execution.output_file(sfadir + "/[OSD or fieldsign]/eccen.masked.nii"),
        polar_masked=execution.output_file(sfadir + "/[OSD or fieldsign]/polar.masked.nii"),
        eccen_masked_mgh=execution.output_file(sfadir + "/[OSD or fieldsign]/?h.eccen.masked.mgh"),
        polar_masked_mgh=execution.output_file(sfadir + "/[OSD or fieldsign]/?h.polar.masked.mgh"),
        fieldsign_masked_mgh=execution.output_file(sfadir + "/[OSD or fieldsign]/?h.fieldsign.masked.mgh"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SFA2FIELDSIGN_METADATA",
    "Sfa2fieldsignOutputs",
    "sfa2fieldsign",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_APQC_TSNR_GENERAL_METADATA = Metadata(
    id="a70654cb187bdb9991d41a1bcb7827db58a9c4b0.boutiques",
    name="adjunct_apqc_tsnr_general",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctApqcTsnrGeneralOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_apqc_tsnr_general(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def adjunct_apqc_tsnr_general(
    montgap: str | None = None,
    montcolor: str | None = None,
    montx: str | None = None,
    monty: str | None = None,
    opacity: str | None = None,
    blowup: str | None = None,
    save_ftype: str | None = None,
    set_dicom_xyz: list[str] | None = None,
    set_ijk: list[str] | None = None,
    set_subbricks: list[str] | None = None,
    olay_alpha: str | None = None,
    olay_boxed: str | None = None,
    thr_olay: str | None = None,
    ulay_range_nz: list[str] | None = None,
    ulay_range: list[str] | None = None,
    delta_slices: list[str] | None = None,
    olay_disc_hot_range: list[str] | None = None,
    olay_cont_max: str | None = None,
    cbar_cont: str | None = None,
    no_cor: bool = False,
    no_sag: bool = False,
    no_axi: bool = False,
    echo: bool = False,
    runner: Runner | None = None,
) -> AdjunctApqcTsnrGeneralOutputs:
    """
    An adjunct program for making TSNR plots for APQC.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        montgap: Specify montage gap.
        montcolor: Specify montage color.
        montx: Specify montage x coordinate.
        monty: Specify montage y coordinate.
        opacity: Specify overlay opacity.
        blowup: Specify blowup factor.
        save_ftype: Specify save file type.
        set_dicom_xyz: Set DICOM x, y, z coordinates.
        set_ijk: Set IJK coordinates.
        set_subbricks: Set sub-bricks.
        olay_alpha: Specify overlay alpha.
        olay_boxed: Specify boxed overlay.
        thr_olay: Specify threshold for overlay.
        ulay_range_nz: Specify non-zero range for underlay.
        ulay_range: Specify range for underlay.
        delta_slices: Specify delta slices.
        olay_disc_hot_range: Specify discrete hot range for overlay.
        olay_cont_max: Specify continuous max for overlay.
        cbar_cont: Specify continuous color bar.
        no_cor: No coronal view.
        no_sag: No sagittal view.
        no_axi: No axial view.
        echo: Echo the command line arguments.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctApqcTsnrGeneralOutputs`).
    """
    if set_dicom_xyz is not None and not (len(set_dicom_xyz) <= 3): 
        raise ValueError(f"Length of 'set_dicom_xyz' must be less than 3 but was {len(set_dicom_xyz)}")
    if set_ijk is not None and not (len(set_ijk) <= 3): 
        raise ValueError(f"Length of 'set_ijk' must be less than 3 but was {len(set_ijk)}")
    if set_subbricks is not None and not (len(set_subbricks) <= 3): 
        raise ValueError(f"Length of 'set_subbricks' must be less than 3 but was {len(set_subbricks)}")
    if ulay_range_nz is not None and not (len(ulay_range_nz) <= 2): 
        raise ValueError(f"Length of 'ulay_range_nz' must be less than 2 but was {len(ulay_range_nz)}")
    if ulay_range is not None and not (len(ulay_range) <= 2): 
        raise ValueError(f"Length of 'ulay_range' must be less than 2 but was {len(ulay_range)}")
    if delta_slices is not None and not (len(delta_slices) <= 3): 
        raise ValueError(f"Length of 'delta_slices' must be less than 3 but was {len(delta_slices)}")
    if olay_disc_hot_range is not None and not (len(olay_disc_hot_range) <= 2): 
        raise ValueError(f"Length of 'olay_disc_hot_range' must be less than 2 but was {len(olay_disc_hot_range)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_APQC_TSNR_GENERAL_METADATA)
    cargs = []
    cargs.append("adjunct_apqc_tsnr_general")
    if montgap is not None:
        cargs.extend([
            "-montgap",
            montgap
        ])
    if montcolor is not None:
        cargs.extend([
            "-montcolor",
            montcolor
        ])
    if montx is not None:
        cargs.extend([
            "-montx",
            montx
        ])
    if monty is not None:
        cargs.extend([
            "-monty",
            monty
        ])
    if opacity is not None:
        cargs.extend([
            "-opacity",
            opacity
        ])
    if blowup is not None:
        cargs.extend([
            "-blowup",
            blowup
        ])
    if save_ftype is not None:
        cargs.extend([
            "-save_ftype",
            save_ftype
        ])
    if set_dicom_xyz is not None:
        cargs.extend([
            "-set_dicom_xyz",
            *set_dicom_xyz
        ])
    if set_ijk is not None:
        cargs.extend([
            "-set_ijk",
            *set_ijk
        ])
    if set_subbricks is not None:
        cargs.extend([
            "-set_subbricks",
            *set_subbricks
        ])
    if olay_alpha is not None:
        cargs.extend([
            "-olay_alpha",
            olay_alpha
        ])
    if olay_boxed is not None:
        cargs.extend([
            "-olay_boxed",
            olay_boxed
        ])
    if thr_olay is not None:
        cargs.extend([
            "-thr_olay",
            thr_olay
        ])
    if ulay_range_nz is not None:
        cargs.extend([
            "-ulay_range_nz",
            *ulay_range_nz
        ])
    if ulay_range is not None:
        cargs.extend([
            "-ulay_range",
            *ulay_range
        ])
    if delta_slices is not None:
        cargs.extend([
            "-delta_slices",
            *delta_slices
        ])
    if olay_disc_hot_range is not None:
        cargs.extend([
            "-olay_disc_hot_range",
            *olay_disc_hot_range
        ])
    if olay_cont_max is not None:
        cargs.extend([
            "-olay_cont_max",
            olay_cont_max
        ])
    if cbar_cont is not None:
        cargs.extend([
            "-cbar_cont",
            cbar_cont
        ])
    if no_cor:
        cargs.append("-no_cor")
    if no_sag:
        cargs.append("-no_sag")
    if no_axi:
        cargs.append("-no_axi")
    if echo:
        cargs.append("-echo")
    ret = AdjunctApqcTsnrGeneralOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_APQC_TSNR_GENERAL_METADATA",
    "AdjunctApqcTsnrGeneralOutputs",
    "adjunct_apqc_tsnr_general",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LOG_LIKELIHOOD_METADATA = Metadata(
    id="f22fe6123ce8f0f860ffe7eecd35b5f18caff0af.boutiques",
    name="mri_log_likelihood",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLogLikelihoodOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_log_likelihood(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_log_likelihood(
    input_brain_images: list[InputPathType],
    atlas_file: InputPathType,
    transform_file: InputPathType,
    runner: Runner | None = None,
) -> MriLogLikelihoodOutputs:
    """
    MRI log likelihood calculation tool for brain images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_brain_images: List of input brain images.
        atlas_file: Atlas image file.
        transform_file: Transform file for registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLogLikelihoodOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LOG_LIKELIHOOD_METADATA)
    cargs = []
    cargs.append("mri_log_likelihood")
    cargs.extend([execution.input_file(f) for f in input_brain_images])
    cargs.append(execution.input_file(atlas_file))
    cargs.append(execution.input_file(transform_file))
    ret = MriLogLikelihoodOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LOG_LIKELIHOOD_METADATA",
    "MriLogLikelihoodOutputs",
    "mri_log_likelihood",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_ENTS_METADATA = Metadata(
    id="f66a5a56bce20baecbbcffc7deaf985412131450.boutiques",
    name="fsl_ents",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslEntsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_ents(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_time_series: OutputPathType | None
    """File to save time series to"""


def fsl_ents(
    icadir: str,
    components: list[str],
    outfile: InputPathType | None = None,
    overwrite: bool = False,
    conffile: list[InputPathType] | None = None,
    runner: Runner | None = None,
) -> FslEntsOutputs:
    """
    Extract component time series from a MELODIC .ica directory.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        icadir: .ica directory to extract time series from.
        components: Component number or FIX/AROMA file specifying components to\
            extract.
        outfile: File to save time series to.
        overwrite: Overwrite output file if it exists.
        conffile: Extra files to append to output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslEntsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_ENTS_METADATA)
    cargs = []
    cargs.append("fsl_ents")
    cargs.append(icadir)
    cargs.extend(components)
    if outfile is not None:
        cargs.extend([
            "-o",
            execution.input_file(outfile)
        ])
    if overwrite:
        cargs.append("-ow")
    if conffile is not None:
        cargs.extend([
            "-c",
            *[execution.input_file(f) for f in conffile]
        ])
    cargs.append("[-h]")
    ret = FslEntsOutputs(
        root=execution.output_file("."),
        out_time_series=execution.output_file(pathlib.Path(outfile).name) if (outfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_ENTS_METADATA",
    "FslEntsOutputs",
    "fsl_ents",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_APARC2ASEG_METADATA = Metadata(
    id="70399c00183edd73f6d174d9a1c242615869d650.boutiques",
    name="mri_aparc2aseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriAparc2asegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_aparc2aseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Output segmentation volume."""


def mri_aparc2aseg(
    subject: str | None = None,
    output_volfile: str | None = None,
    old_ribbon: bool = False,
    new_ribbon: bool = False,
    a2005s: bool = False,
    a2009s: bool = False,
    annot_name: str | None = None,
    annot_table: str | None = None,
    base_offset: float | None = None,
    label_wm: bool = False,
    wmparc_dmax: float | None = None,
    rip_unknown: bool = False,
    hypo_as_wm: bool = False,
    no_fix_parahip: bool = False,
    smooth_normals: float | None = None,
    crs_test: str | None = None,
    right_hemisphere: bool = False,
    threads: float | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriAparc2asegOutputs:
    """
    Maps the cortical labels from the automatic cortical parcellation to the
    automatic segmentation volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Name of the subject as found in the SUBJECTS_DIR.
        output_volfile: Full path of file to save the output segmentation in.\
            Default is mri/aparc+aseg.mgz.
        old_ribbon: Use mri/hemi.ribbon.mgz as a mask for the cortex.
        new_ribbon: Mask cortical voxels with mri/ribbon.mgz. Same as --volmask.
        a2005s: Use ?h.aparc.a2005s.annot. Output will be\
            aparc.a2005s+aseg.mgz.
        a2009s: Use ?h.aparc.a2009s.annot. Output will be\
            aparc.a2009s+aseg.mgz.
        annot_name: Use annotname surface annotation. By default, uses\
            ?h.aparc.annot.
        annot_table: Annotation table file. Default is\
            $FREESURFER_HOME/Simple_surface_labels2009.txt.
        base_offset: Add offset to all segmentation ids.
        label_wm: Re-assign white matter voxel labels to the closest cortical\
            point if within distance.
        wmparc_dmax: Max distance (mm) from cortex to be labeled as gyral WM\
            (default 5mm).
        rip_unknown: Do not label WM based on 'unknown' cortical label.
        hypo_as_wm: Label hypointensities as WM.
        no_fix_parahip: Do not remove unconnected regions from WM parahip.
        smooth_normals: Change number of surface normal smoothing steps\
            (default is 10).
        crs_test: Test mapping of column, row, slice.
        right_hemisphere: Only process the right hemisphere.
        threads: Run in parallel with the specified number of threads.
        help_: Print out information on how to use this program.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriAparc2asegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_APARC2ASEG_METADATA)
    cargs = []
    cargs.append("mri_aparc2aseg")
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if output_volfile is not None:
        cargs.extend([
            "--o",
            output_volfile
        ])
    if old_ribbon:
        cargs.append("--old-ribbon")
    if new_ribbon:
        cargs.append("--new-ribbon")
    if a2005s:
        cargs.append("--a2005s")
    if a2009s:
        cargs.append("--a2009s")
    if annot_name is not None:
        cargs.extend([
            "--annot",
            annot_name
        ])
    if annot_table is not None:
        cargs.extend([
            "--annot-table",
            annot_table
        ])
    if base_offset is not None:
        cargs.extend([
            "--base-offset",
            str(base_offset)
        ])
    if label_wm:
        cargs.append("--labelwm")
    if wmparc_dmax is not None:
        cargs.extend([
            "--wmparc-dmax",
            str(wmparc_dmax)
        ])
    if rip_unknown:
        cargs.append("--rip-unknown")
    if hypo_as_wm:
        cargs.append("--hypo-as-wm")
    if no_fix_parahip:
        cargs.append("--no-fix-parahip")
    if smooth_normals is not None:
        cargs.extend([
            "--smooth_normals",
            str(smooth_normals)
        ])
    if crs_test is not None:
        cargs.extend([
            "--crs-test",
            crs_test
        ])
    if right_hemisphere:
        cargs.append("--rh")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MriAparc2asegOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file("mri/aparc+aseg.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_APARC2ASEG_METADATA",
    "MriAparc2asegOutputs",
    "mri_aparc2aseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CONCATENATE_GCAM_METADATA = Metadata(
    id="f2136516d8c43c1484d6b8f54f1f6627fae4ebe7.boutiques",
    name="mri_concatenate_gcam",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriConcatenateGcamOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_concatenate_gcam(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Composite LTA or M3Z transform, depending on input."""


def mri_concatenate_gcam(
    inputs: list[InputPathType],
    output: str,
    source_image: InputPathType | None = None,
    target_image: InputPathType | None = None,
    reduce: bool = False,
    invert: bool = False,
    downsample: bool = False,
    runner: Runner | None = None,
) -> MriConcatenateGcamOutputs:
    """
    Concatenate a combination of input LTAs (linear transform array) and GCAMs
    (Gaussian classifier atlas, M3Z).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        inputs: Combination of input LTAs and M3Zs.
        output: Concatenated output transform, saved as an LTA or M3Z depending\
            on the input transforms.
        source_image: Change source image geometry of output M3Z, useful for\
            GCAM inversion if the path of the original source volume changed.
        target_image: Change destination image geometry of output M3Z.
        reduce: Reduce output LTA to single LT.
        invert: Invert the output transform.
        downsample: Downsample output M3Z to spacing of 2; by default, the\
            output spacing is that of the rightmost input M3Z.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriConcatenateGcamOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CONCATENATE_GCAM_METADATA)
    cargs = []
    cargs.append("mri_concatenate_gcam")
    cargs.extend([execution.input_file(f) for f in inputs])
    cargs.append(output)
    if source_image is not None:
        cargs.extend([
            "-s",
            execution.input_file(source_image)
        ])
    if target_image is not None:
        cargs.extend([
            "-t",
            execution.input_file(target_image)
        ])
    if reduce:
        cargs.append("-r")
    if invert:
        cargs.append("-i")
    if downsample:
        cargs.append("-d")
    ret = MriConcatenateGcamOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CONCATENATE_GCAM_METADATA",
    "MriConcatenateGcamOutputs",
    "mri_concatenate_gcam",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_RF_LABEL_METADATA = Metadata(
    id="4696827fae4b209c83ac56d628b74442e0fa9ece.boutiques",
    name="mri_rf_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriRfLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_rf_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outvol: OutputPathType
    """Output volume from mri_ca_label"""


def mri_rf_label(
    input_volumes: list[InputPathType],
    transform_file: InputPathType,
    gcafile: InputPathType,
    output_volume: str,
    cross_sequence_flag: bool = False,
    nogibbs_flag: bool = False,
    wm_path: InputPathType | None = None,
    conform_flag: bool = False,
    normpd_flag: bool = False,
    gca_tl: InputPathType | None = None,
    debug_voxel: list[float] | None = None,
    debug_node: list[float] | None = None,
    debug_label: float | None = None,
    tr: float | None = None,
    te: float | None = None,
    alpha: float | None = None,
    example: list[InputPathType] | None = None,
    pthresh: float | None = 0.7,
    niter: float | None = 2,
    novar_flag: bool = False,
    regularize: float | None = None,
    nohippo_flag: bool = False,
    fwm: InputPathType | None = None,
    mri_vol: InputPathType | None = None,
    heq: InputPathType | None = None,
    renorm: InputPathType | None = None,
    flash_flag: bool = False,
    flash_params: InputPathType | None = None,
    renormalize: list[float] | None = None,
    set_input: InputPathType | None = None,
    histogram_flag: bool = False,
    cond_density_mean: float | None = None,
    snapshots: list[str] | None = None,
    mask: InputPathType | None = None,
    expand: float | None = None,
    max_iter: float | None = 200,
    filter_mode: list[float] | None = [0, 0.5],
    longitudinal_vol: InputPathType | None = None,
    longitudinal_lta: InputPathType | None = None,
    relabel_unlikely_flag: list[float] | None = None,
    runner: Runner | None = None,
) -> MriRfLabelOutputs:
    """
    MRI automatic tissue labeling using a Gaussian Classifier Atlas (GCA).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volumes: Input volume(s).
        transform_file: Transform file.
        gcafile: GCA file.
        output_volume: Output volume.
        cross_sequence_flag: Label a volume acquired with a sequence different\
            than atlas.
        nogibbs_flag: Disable gibbs priors.
        wm_path: Use WM segmentation from provided file.
        conform_flag: Interpolate volume to be isotropic 1mm^3.
        normpd_flag: Normalize PD image to GCA means.
        gca_tl: Use file to label the thin temporal lobe.
        debug_voxel: Debug voxel at specified coordinates.
        debug_node: Debug node at specified coordinates.
        debug_label: Debug label at specified index.
        tr: Set TR in msec.
        te: Set TE in msec.
        alpha: Set alpha in radians.
        example: Use T1 (mri_vol) and segmentation as example.
        pthresh: Use p threshold for adaptive renormalization.
        niter: Apply max likelihood for n iterations.
        novar_flag: Do not use variance in classification.
        regularize: Regularize variance to be sigma+nC(noise).
        nohippo_flag: Do not auto-edit hippocampus.
        fwm: Use fixed white matter segmentation from wm.
        mri_vol: Write most likely MR volume to specified file.
        heq: Use histogram equalization from specified volume.
        renorm: Renormalize using predicted intensity values.
        flash_flag: Use FLASH forward model to predict intensity values.
        flash_params: Use FLASH forward model and tissue params from file.
        renormalize: Renorm class means iter times after initial label with\
            window of wsize.
        set_input: Set input volume.
        histogram_flag: Use GCA to histogram normalize input image.
        cond_density_mean: Mean filter n times to conditional densities.
        snapshots: Write snapshots of gibbs process every n times to filename.
        mask: Use mri_vol to mask final labeling.
        expand: Expand.
        max_iter: Set max iterations.
        filter_mode: Filter labeled volume with threshold t mode filter f times.
        longitudinal_vol: Longitudinal processing: mri_vol is label from tp1,\
            LTA is registration from tp1 to current data.
        longitudinal_lta: Longitudinal LTA registration.
        relabel_unlikely_flag: Reclassify voxels using a Gaussian window to\
            recomute priors and likelihoods.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriRfLabelOutputs`).
    """
    if snapshots is not None and (len(snapshots) != 2): 
        raise ValueError(f"Length of 'snapshots' must be 2 but was {len(snapshots)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_RF_LABEL_METADATA)
    cargs = []
    cargs.append("mri_rf_label")
    cargs.extend([execution.input_file(f) for f in input_volumes])
    cargs.append(execution.input_file(transform_file))
    cargs.append(execution.input_file(gcafile))
    cargs.append(output_volume)
    if cross_sequence_flag:
        cargs.append("-cross-sequence")
    if nogibbs_flag:
        cargs.append("-nogibbs")
    if wm_path is not None:
        cargs.extend([
            "-wm",
            execution.input_file(wm_path)
        ])
    if conform_flag:
        cargs.append("-conform")
    if normpd_flag:
        cargs.append("-normpd")
    if gca_tl is not None:
        cargs.extend([
            "-tl",
            execution.input_file(gca_tl)
        ])
    if debug_voxel is not None:
        cargs.extend([
            "-debug_voxel",
            *map(str, debug_voxel)
        ])
    if debug_node is not None:
        cargs.extend([
            "-debug_node",
            *map(str, debug_node)
        ])
    if debug_label is not None:
        cargs.extend([
            "-debug_label",
            str(debug_label)
        ])
    if tr is not None:
        cargs.extend([
            "-tr",
            str(tr)
        ])
    if te is not None:
        cargs.extend([
            "-te",
            str(te)
        ])
    if alpha is not None:
        cargs.extend([
            "-alpha",
            str(alpha)
        ])
    if example is not None:
        cargs.extend([
            "-example",
            *[execution.input_file(f) for f in example]
        ])
    if pthresh is not None:
        cargs.extend([
            "-pthresh",
            str(pthresh)
        ])
    if niter is not None:
        cargs.extend([
            "-niter",
            str(niter)
        ])
    if novar_flag:
        cargs.append("-novar")
    if regularize is not None:
        cargs.extend([
            "-regularize",
            str(regularize)
        ])
    if nohippo_flag:
        cargs.append("-nohippo")
    if fwm is not None:
        cargs.extend([
            "-fwm",
            execution.input_file(fwm)
        ])
    if mri_vol is not None:
        cargs.extend([
            "-mri",
            execution.input_file(mri_vol)
        ])
    if heq is not None:
        cargs.extend([
            "-heq",
            execution.input_file(heq)
        ])
    if renorm is not None:
        cargs.extend([
            "-renorm",
            execution.input_file(renorm)
        ])
    if flash_flag:
        cargs.append("-flash")
    if flash_params is not None:
        cargs.extend([
            "-flash_params",
            execution.input_file(flash_params)
        ])
    if renormalize is not None:
        cargs.extend([
            "-renormalize",
            *map(str, renormalize)
        ])
    if set_input is not None:
        cargs.extend([
            "-r",
            execution.input_file(set_input)
        ])
    if histogram_flag:
        cargs.append("-h")
    if cond_density_mean is not None:
        cargs.extend([
            "-a",
            str(cond_density_mean)
        ])
    if snapshots is not None:
        cargs.extend([
            "-w",
            *snapshots
        ])
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if expand is not None:
        cargs.extend([
            "-e",
            str(expand)
        ])
    if max_iter is not None:
        cargs.extend([
            "-n",
            str(max_iter)
        ])
    if filter_mode is not None:
        cargs.extend([
            "-f",
            *map(str, filter_mode)
        ])
    if longitudinal_vol is not None:
        cargs.extend([
            "-L",
            execution.input_file(longitudinal_vol)
        ])
    if longitudinal_lta is not None:
        cargs.append(execution.input_file(longitudinal_lta))
    if relabel_unlikely_flag is not None:
        cargs.extend([
            "-RELABEL_UNLIKELY",
            *map(str, relabel_unlikely_flag)
        ])
    ret = MriRfLabelOutputs(
        root=execution.output_file("."),
        outvol=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_RF_LABEL_METADATA",
    "MriRfLabelOutputs",
    "mri_rf_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CA_DEFORM_METADATA = Metadata(
    id="7a76a6060e94710386328206ab18f500335fc348.boutiques",
    name="mris_ca_deform",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCaDeformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_ca_deform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    deformed_surface: OutputPathType
    """The result of the deformation process, output surface file."""


def mris_ca_deform(
    input_surface: InputPathType,
    label_vol: InputPathType,
    transform: InputPathType,
    intensity_vol: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisCaDeformOutputs:
    """
    Deforms a surface to match it to a volumetric map of cortical labels.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: The input surface file to be deformed.
        label_vol: The input volumetric label map.
        transform: The transform file, typically a matrix that aligns the\
            volumes.
        intensity_vol: The intensity volume that is used in the deformation\
            process.
        output_surface: The file name for the output, deformed surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCaDeformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CA_DEFORM_METADATA)
    cargs = []
    cargs.append("mris_ca_deform")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(label_vol))
    cargs.append(execution.input_file(transform))
    cargs.append(execution.input_file(intensity_vol))
    cargs.append(output_surface)
    ret = MrisCaDeformOutputs(
        root=execution.output_file("."),
        deformed_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CA_DEFORM_METADATA",
    "MrisCaDeformOutputs",
    "mris_ca_deform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_ROBUST_REGISTER_METADATA = Metadata(
    id="fe2158f128fa82fc3156d764c03ca5f6fec2935c.boutiques",
    name="mri_robust_register",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriRobustRegisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_robust_register(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reg_output: OutputPathType
    """Registration output file containing the transformation from movable to
    destination."""
    mapped_output: OutputPathType | None
    """Movable volume mapped and resampled at destination."""
    mapped_hdr_output: OutputPathType | None
    """Movable volume aligned to destination (header only)."""
    weights_output_file: OutputPathType | None
    """Weights indicating outlier probabilities in destination space."""
    iscale_out_file: OutputPathType | None
    """Output text file containing the intensity scale value."""
    half_mov_file: OutputPathType | None
    """Half-way movable volume resampled."""
    half_dst_file: OutputPathType | None
    """Half-way destination volume resampled."""
    half_weights_file: OutputPathType | None
    """Half-way weights resampled in halfway space."""
    half_mov_lta_file: OutputPathType | None
    """Transform output from movable to half-way space."""
    half_dst_lta_file: OutputPathType | None
    """Transform output from destination to half-way space."""
    ent_mov_file: OutputPathType | None
    """Movable entropy image for ROBENT cost function."""
    ent_dst_file: OutputPathType | None
    """Target entropy image for ROBENT cost function."""


def mri_robust_register(
    movable_volume: InputPathType,
    target_volume: InputPathType,
    output_registration: str,
    outlier_sensitivity: float | None = None,
    satit: bool = False,
    mapped_movable: str | None = None,
    mapped_movable_hdr: str | None = None,
    weights: str | None = None,
    oneminus_w: bool = False,
    iscale: bool = False,
    iscale_only: bool = False,
    iscale_out: str | None = None,
    iscale_in: str | None = None,
    trans_only: bool = False,
    affine: bool = False,
    ixform: str | None = None,
    init_orient: bool = False,
    no_init: bool = False,
    vox2vox: bool = False,
    cost: str | None = None,
    ent_radius: float | None = None,
    ent_correction: bool = False,
    ent_ball: bool = False,
    ent_mov: str | None = None,
    powell_tolerance: float | None = None,
    sobel: bool = False,
    no_sym: bool = False,
    maximum_iterations: float | None = None,
    ent_dst: str | None = None,
    high_iter: float | None = None,
    eps_iteration: float | None = None,
    no_multiscale: bool = False,
    max_size: float | None = None,
    min_size: float | None = None,
    w_limit: float | None = None,
    sub_sample: float | None = None,
    float_type: bool = False,
    white_bg_mov: bool = False,
    white_bg_dst: bool = False,
    uchar: bool = False,
    mask_mov: InputPathType | None = None,
    mask_dst: InputPathType | None = None,
    half_mov: str | None = None,
    half_dst: str | None = None,
    half_weights: str | None = None,
    half_mov_lta: str | None = None,
    half_dst_lta: str | None = None,
    debug: bool = False,
    verbose: float | None = None,
    runner: Runner | None = None,
) -> MriRobustRegisterOutputs:
    """
    Inverse consistent registration of two volumes using robust and standard cost
    functions.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        movable_volume: Input movable volume to be aligned to target.
        target_volume: Input target volume.
        output_registration: Output registration (transform from mov to dst).
        outlier_sensitivity: Set outlier sensitivity manually for robust cost\
            functions. Higher values mean less sensitivity.
        satit: Auto-detect good sensitivity for robust cost functions.
        mapped_movable: Output image: movable mapped and resampled at\
            destination.
        mapped_movable_hdr: Output image: movable aligned to destination (no\
            resampling, only adjusting header vox2ras).
        weights: Output weights (outlier probabilities) in destination space\
            (0=regular,1=outlier).
        oneminus_w: Weights (outlier) map will be inverted (0=outlier), as in\
            earlier versions.
        iscale: Estimate intensity scale factor.
        iscale_only: Only perform intensity scaling (no transformation).
        iscale_out: Output text file for iscale value.
        iscale_in: Initial input text file for iscale value.
        trans_only: Find 3 parameter translation only.
        affine: Find 12 parameter affine transform.
        ixform: Use initial transform LTA on source.
        init_orient: Use moments for orientation initialization.
        no_init: Skip automatic transform initialization.
        vox2vox: Output VOX2VOX LTA file.
        cost: Set cost function for registration.
        ent_radius: With ROBENT: specify box radius for entropy computation.
        ent_correction: With ROBENT: use better entropy computation that works\
            on smaller boxes.
        ent_ball: With ROBENT: use ball around voxel instead of box.
        ent_mov: With ROBENT: write movable entropy image.
        powell_tolerance: With MI, NMI etc: set Powell tolerance.
        sobel: Register Sobel magnitude images.
        no_sym: Do not map to half way space.
        maximum_iterations: Maximum number of iterations on each resolution.
        ent_dst: With ROBENT: write target entropy image.
        high_iter: Maximum number of iterations on highest resolution.
        eps_iteration: Stop iterations when transform update falls below\
            specified RMS distance.
        no_multiscale: Process highest resolution only (no multiscale).
        max_size: Specify largest voxel dimension for gaussian pyramid.
        min_size: Specify smallest voxel dimension for gaussian pyramid.
        w_limit: (Expert) sets maximal outlier limit for --satit.
        sub_sample: Subsample if dimension is greater than the specified value\
            on all axes.
        float_type: Convert images to float internally.
        white_bg_mov: Assume white background in MOV for padding.
        white_bg_dst: Assume white background in DST for padding.
        uchar: Convert inputs to UCHAR with rescale and histogram cropping.
        mask_mov: Mask movable image with mask file.
        mask_dst: Mask destination image with mask file.
        half_mov: Outputs half-way movable (resampled in halfway space).
        half_dst: Outputs half-way destination (resampled in halfway space).
        half_weights: Outputs half-way weights (resampled in halfway space).
        half_mov_lta: Outputs transform from movable to half-way space.
        half_dst_lta: Outputs transform from destination to half-way space.
        debug: Show debug output.
        verbose: Verbosity level: 0 (quiet), 1 (normal), 2 (detail).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriRobustRegisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_ROBUST_REGISTER_METADATA)
    cargs = []
    cargs.append("mri_robust_register")
    cargs.extend([
        "-mov",
        execution.input_file(movable_volume)
    ])
    cargs.extend([
        "-dst",
        execution.input_file(target_volume)
    ])
    cargs.extend([
        "-lta",
        output_registration
    ])
    if outlier_sensitivity is not None:
        cargs.extend([
            "--sat",
            str(outlier_sensitivity)
        ])
    if satit:
        cargs.append("--satit")
    if mapped_movable is not None:
        cargs.extend([
            "--mapmov",
            mapped_movable
        ])
    if mapped_movable_hdr is not None:
        cargs.extend([
            "--mapmovhdr",
            mapped_movable_hdr
        ])
    if weights is not None:
        cargs.extend([
            "--weights",
            weights
        ])
    if oneminus_w:
        cargs.append("--oneminusw")
    if iscale:
        cargs.append("--iscale")
    if iscale_only:
        cargs.append("--iscaleonly")
    if iscale_out is not None:
        cargs.extend([
            "--iscaleout",
            iscale_out
        ])
    if iscale_in is not None:
        cargs.extend([
            "--iscalein",
            iscale_in
        ])
    if trans_only:
        cargs.append("--transonly")
    if affine:
        cargs.append("--affine")
    if ixform is not None:
        cargs.extend([
            "--ixform",
            ixform
        ])
    if init_orient:
        cargs.append("--initorient")
    if no_init:
        cargs.append("--noinit")
    if vox2vox:
        cargs.append("--vox2vox")
    if cost is not None:
        cargs.extend([
            "--cost",
            cost
        ])
    if ent_radius is not None:
        cargs.extend([
            "--entradius",
            str(ent_radius)
        ])
    if ent_correction:
        cargs.append("--entcorrection")
    if ent_ball:
        cargs.append("--entball")
    if ent_mov is not None:
        cargs.extend([
            "--entmov",
            ent_mov
        ])
    if powell_tolerance is not None:
        cargs.extend([
            "--powelltol",
            str(powell_tolerance)
        ])
    if sobel:
        cargs.append("--sobel")
    if no_sym:
        cargs.append("--nosym")
    if maximum_iterations is not None:
        cargs.extend([
            "--maxit",
            str(maximum_iterations)
        ])
    if ent_dst is not None:
        cargs.extend([
            "--entdst",
            ent_dst
        ])
    if high_iter is not None:
        cargs.extend([
            "--highit",
            str(high_iter)
        ])
    if eps_iteration is not None:
        cargs.extend([
            "--epsit",
            str(eps_iteration)
        ])
    if no_multiscale:
        cargs.append("--nomulti")
    if max_size is not None:
        cargs.extend([
            "--maxsize",
            str(max_size)
        ])
    if min_size is not None:
        cargs.extend([
            "--minsize",
            str(min_size)
        ])
    if w_limit is not None:
        cargs.extend([
            "--wlimit",
            str(w_limit)
        ])
    if sub_sample is not None:
        cargs.extend([
            "--subsample",
            str(sub_sample)
        ])
    if float_type:
        cargs.append("--floattype")
    if white_bg_mov:
        cargs.append("--whitebgmov")
    if white_bg_dst:
        cargs.append("--whitebgdst")
    if uchar:
        cargs.append("--uchar")
    if mask_mov is not None:
        cargs.extend([
            "--maskmov",
            execution.input_file(mask_mov)
        ])
    if mask_dst is not None:
        cargs.extend([
            "--maskdst",
            execution.input_file(mask_dst)
        ])
    if half_mov is not None:
        cargs.extend([
            "--halfmov",
            half_mov
        ])
    if half_dst is not None:
        cargs.extend([
            "--halfdst",
            half_dst
        ])
    if half_weights is not None:
        cargs.extend([
            "--halfweights",
            half_weights
        ])
    if half_mov_lta is not None:
        cargs.extend([
            "--halfmovlta",
            half_mov_lta
        ])
    if half_dst_lta is not None:
        cargs.extend([
            "--halfdstlta",
            half_dst_lta
        ])
    if debug:
        cargs.append("--debug")
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    ret = MriRobustRegisterOutputs(
        root=execution.output_file("."),
        reg_output=execution.output_file(output_registration),
        mapped_output=execution.output_file(mapped_movable) if (mapped_movable is not None) else None,
        mapped_hdr_output=execution.output_file(mapped_movable_hdr) if (mapped_movable_hdr is not None) else None,
        weights_output_file=execution.output_file(weights) if (weights is not None) else None,
        iscale_out_file=execution.output_file(iscale_out) if (iscale_out is not None) else None,
        half_mov_file=execution.output_file(half_mov) if (half_mov is not None) else None,
        half_dst_file=execution.output_file(half_dst) if (half_dst is not None) else None,
        half_weights_file=execution.output_file(half_weights) if (half_weights is not None) else None,
        half_mov_lta_file=execution.output_file(half_mov_lta) if (half_mov_lta is not None) else None,
        half_dst_lta_file=execution.output_file(half_dst_lta) if (half_dst_lta is not None) else None,
        ent_mov_file=execution.output_file(ent_mov) if (ent_mov is not None) else None,
        ent_dst_file=execution.output_file(ent_dst) if (ent_dst is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_ROBUST_REGISTER_METADATA",
    "MriRobustRegisterOutputs",
    "mri_robust_register",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS2RGB_METADATA = Metadata(
    id="818f21a5949f0f382881eefc95f28854696728c3.boutiques",
    name="mris2rgb",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Mris2rgbOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris2rgb(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris2rgb(
    library_path: str,
    runner: Runner | None = None,
) -> Mris2rgbOutputs:
    """
    A tool from FreeSurfer for converting MRI surface files to RGB images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        library_path: Path to the directory containing the libGLU.so.1 library\
            required by mris2rgb.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Mris2rgbOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS2RGB_METADATA)
    cargs = []
    cargs.append("mris2rgb")
    cargs.extend([
        "export LD_LIBRARY_PATH=",
        library_path
    ])
    ret = Mris2rgbOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS2RGB_METADATA",
    "Mris2rgbOutputs",
    "mris2rgb",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_REGISTRATION_SY_NQUICK_SH_METADATA = Metadata(
    id="95f42ebdf9e80a10a0b738811253de777466a830.boutiques",
    name="antsRegistrationSyNQuick.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsRegistrationSyNquickShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_registration_sy_nquick_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform: OutputPathType
    """Affine transformation matrix resulting from registration."""
    output_warp: OutputPathType
    """Warp field resulting from the registration."""
    output_inverse_warp: OutputPathType
    """Inverse warp field resulting from the registration."""
    output_warped_image: OutputPathType
    """Warped moving image."""


def ants_registration_sy_nquick_sh(
    dimensionality: typing.Literal[2, 3],
    fixed_image: InputPathType,
    moving_image: InputPathType,
    output_prefix: str,
    transform_type: typing.Literal["s", "b"] | None = None,
    runner: Runner | None = None,
) -> AntsRegistrationSyNquickShOutputs:
    """
    A script to quickly compute a SyN-based registration between two images using
    ANTS.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimensionality: Dimensionality of the images (2 or 3).
        fixed_image: Fixed image to which the moving image is registered.
        moving_image: Moving image that is registered to the fixed image.
        output_prefix: Prefix for the output files.
        transform_type: Type of transform: 's' for SyN, 'b' for B-spline SyN.\
            Default is 's'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsRegistrationSyNquickShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_REGISTRATION_SY_NQUICK_SH_METADATA)
    cargs = []
    cargs.append("antsRegistrationSyNQuick.sh")
    cargs.extend([
        "-d",
        str(dimensionality)
    ])
    cargs.extend([
        "-f",
        execution.input_file(fixed_image)
    ])
    cargs.extend([
        "-m",
        execution.input_file(moving_image)
    ])
    cargs.extend([
        "-o",
        output_prefix
    ])
    if transform_type is not None:
        cargs.append(transform_type)
    ret = AntsRegistrationSyNquickShOutputs(
        root=execution.output_file("."),
        output_transform=execution.output_file(output_prefix + "0GenericAffine.mat"),
        output_warp=execution.output_file(output_prefix + "1Warp.nii.gz"),
        output_inverse_warp=execution.output_file(output_prefix + "1InverseWarp.nii.gz"),
        output_warped_image=execution.output_file(output_prefix + "Warped.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_REGISTRATION_SY_NQUICK_SH_METADATA",
    "AntsRegistrationSyNquickShOutputs",
    "ants_registration_sy_nquick_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DEPTH_MAP_METADATA = Metadata(
    id="4a6704d8156d9e0a414515196af7b7f69ca298eb.boutiques",
    name="3dDepthMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDepthMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_depth_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Main output file"""


def v_3d_depth_map(
    input_dataset: InputPathType,
    output_prefix: str,
    mask: InputPathType | None = None,
    dist_squared: bool = False,
    ignore_voxdims: bool = False,
    rimify: float | None = None,
    zeros_are_zero: bool = False,
    zeros_are_neg: bool = False,
    nz_are_neg: bool = False,
    bounds_are_not_zero: bool = False,
    only2_d: str | None = None,
    binary_only: bool = False,
    verbosity: float | None = None,
    runner: Runner | None = None,
) -> V3dDepthMapOutputs:
    """
    Calculates the Euclidean Distance Transform (EDT) for 3D volumes, allowing
    computation of ROI depth maps and applying various adjustments like masking and
    rimification.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset.
        output_prefix: Output prefix name.
        mask: Mask dataset, applied after the EDT has been calculated.
        dist_squared: Output EDT values as distance squared.
        ignore_voxdims: Ignore voxel dimensions, producing outputs as if each\
            voxel dimension was unity.
        rimify: Output a map of each ROI's boundary layer up to thickness RIM.
        zeros_are_zero: EDT values only reported within nonzero locations of\
            the input dataset.
        zeros_are_neg: EDT values in the zero/background regions will be\
            negative.
        nz_are_neg: EDT values in the nonzero ROI regions will be negative.
        bounds_are_not_zero: Treat FOV boundaries for nonzero ROIs as open\
            (i.e., continue infinitely).
        only2_d: Run EDT in 2D along the specified plane (axi|cor|sag).
        binary_only: Treat the input as a binary mask for a faster calculation.
        verbosity: Manage verbosity when running code (default: 1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDepthMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DEPTH_MAP_METADATA)
    cargs = []
    cargs.append("3dDepthMap")
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if dist_squared:
        cargs.append("-dist_sq")
    if ignore_voxdims:
        cargs.append("-ignore_voxdims")
    if rimify is not None:
        cargs.extend([
            "-rimify",
            str(rimify)
        ])
    if zeros_are_zero:
        cargs.append("-zeros_are_zero")
    if zeros_are_neg:
        cargs.append("-zeros_are_neg")
    if nz_are_neg:
        cargs.append("-nz_are_neg")
    if bounds_are_not_zero:
        cargs.append("-bounds_are_not_zero")
    if only2_d is not None:
        cargs.extend([
            "-only2D",
            only2_d
        ])
    if binary_only:
        cargs.append("-binary_only")
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = V3dDepthMapOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDepthMapOutputs",
    "V_3D_DEPTH_MAP_METADATA",
    "v_3d_depth_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLORIENT_FSL_METADATA = Metadata(
    id="91c87d301655f1a487272843a72c1efbca6dd79a.boutiques",
    name="fslorient.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FslorientFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslorient_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslorient_fsl(
    filename: InputPathType,
    swap_orient: bool = False,
    set_qform: list[float] | None = None,
    set_qform_code: str | None = None,
    runner: Runner | None = None,
) -> FslorientFslOutputs:
    """
    A tool for managing the orientations and orientation headers of NIFTI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        filename: Input image filename.
        swap_orient: Swaps FSL radiological and FSL neurological.
        set_qform: Sets the 16 elements of the qform matrix.
        set_qform_code: Sets qform integer code.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslorientFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLORIENT_FSL_METADATA)
    cargs = []
    cargs.append("fslorient")
    if swap_orient:
        cargs.append("-swaporient")
    cargs.append(execution.input_file(filename))
    if set_qform is not None:
        cargs.extend([
            "-setqform",
            *map(str, set_qform)
        ])
    if set_qform_code is not None:
        cargs.extend([
            "-setqformcode",
            set_qform_code
        ])
    ret = FslorientFslOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLORIENT_FSL_METADATA",
    "FslorientFslOutputs",
    "fslorient_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LABEL2VOL_METADATA = Metadata(
    id="b8585b66c04f6292d2db0caedbd9f154b0b92bab.boutiques",
    name="mri_label2vol",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLabel2volOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_label2vol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_vol: OutputPathType
    """The output volume where each voxel has the label it's assigned to."""
    hits_vol: OutputPathType | None
    """The hit volume file showing number of hits per voxel."""
    label_stat_vol: OutputPathType | None
    """The label stat volume file."""


def mri_label2vol(
    template: InputPathType,
    output_volume: str,
    labels: list[str] | None = None,
    annotation: InputPathType | None = None,
    segmentation: InputPathType | None = None,
    registration: InputPathType | None = None,
    identity_flag: bool = False,
    fill_threshold: float | None = None,
    label_vox_vol: float | None = None,
    projection: str | None = None,
    subject: str | None = None,
    hemisphere: str | None = None,
    hits_volume: str | None = None,
    label_stat_volume: str | None = None,
    stat_threshold: float | None = None,
    offset: float | None = None,
    defects: str | None = None,
    native_vox2ras_flag: bool = False,
    runner: Runner | None = None,
) -> MriLabel2volOutputs:
    """
    Converts a label or a set of labels into a volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        template: Template volume; the output will have the same size and\
            geometry.
        output_volume: Output volume in which each voxel will have the number\
            of the label to which it is assigned.
        labels: Enter the name of the label file. For multiple labels, use\
            multiple --label flags.
        annotation: Surface annotation file. Use this to input annotations\
            directly.
        segmentation: Path to input segmentation.
        registration: tkregister-style registration matrix mapping LabelXYZ to\
            VolXYZ.
        identity_flag: Use the identity matrix as the registration.
        fill_threshold: Threshold for voxel fill; a value between 0 and 1.
        label_vox_vol: Volume of each label point; default is 1mm³.
        projection: Project the label along the surface normal. Type can be abs\
            or frac.
        subject: FREESURFER subject identifier; needed with --proj.
        hemisphere: Hemisphere to use for --proj or --annot. Legal values are\
            lh and rh.
        hits_volume: Hit volume, a multi-frame volume with one frame per label\
            showing the number of hits per voxel.
        label_stat_volume: Map the label stats field into the volume.
        stat_threshold: Only use label point where stat > thresh.
        offset: Add offset to the segmentation numbers.
        defects: Creates a segmentation volume of the surface defects.
        native_vox2ras_flag: Use native voxel-to-RAS transform instead of\
            tkregister-style.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLabel2volOutputs`).
    """
    if fill_threshold is not None and not (0 <= fill_threshold <= 1): 
        raise ValueError(f"'fill_threshold' must be between 0 <= x <= 1 but was {fill_threshold}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LABEL2VOL_METADATA)
    cargs = []
    cargs.append("mri_label2vol")
    if labels is not None:
        cargs.extend([
            "--label",
            *labels
        ])
    if annotation is not None:
        cargs.extend([
            "--annot",
            execution.input_file(annotation)
        ])
    if segmentation is not None:
        cargs.extend([
            "--seg",
            execution.input_file(segmentation)
        ])
    cargs.extend([
        "--temp",
        execution.input_file(template)
    ])
    if registration is not None:
        cargs.extend([
            "--reg",
            execution.input_file(registration)
        ])
    if identity_flag:
        cargs.append("--identity")
    if fill_threshold is not None:
        cargs.extend([
            "--fillthresh",
            str(fill_threshold)
        ])
    if label_vox_vol is not None:
        cargs.extend([
            "--labvoxvol",
            str(label_vox_vol)
        ])
    if projection is not None:
        cargs.extend([
            "--proj",
            projection
        ])
    if subject is not None:
        cargs.extend([
            "--subject",
            subject
        ])
    if hemisphere is not None:
        cargs.extend([
            "--hemi",
            hemisphere
        ])
    cargs.extend([
        "--o",
        output_volume
    ])
    if hits_volume is not None:
        cargs.extend([
            "--hits",
            hits_volume
        ])
    if label_stat_volume is not None:
        cargs.extend([
            "--label-stat",
            label_stat_volume
        ])
    if stat_threshold is not None:
        cargs.extend([
            "--stat-thresh",
            str(stat_threshold)
        ])
    if offset is not None:
        cargs.extend([
            "--offset",
            str(offset)
        ])
    if defects is not None:
        cargs.extend([
            "--defects",
            defects
        ])
    if native_vox2ras_flag:
        cargs.append("--native-vox2ras")
    ret = MriLabel2volOutputs(
        root=execution.output_file("."),
        output_vol=execution.output_file(output_volume),
        hits_vol=execution.output_file(hits_volume) if (hits_volume is not None) else None,
        label_stat_vol=execution.output_file(label_stat_volume) if (label_stat_volume is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LABEL2VOL_METADATA",
    "MriLabel2volOutputs",
    "mri_label2vol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_TIME_METADATA = Metadata(
    id="ca61b3d7c09ab70471b0b19e87ec76f60e282835.boutiques",
    name="fs_time",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsTimeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_time(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resource_output: OutputPathType | None
    """File containing resource usage information."""


def fs_time(
    command: str,
    output_file: str | None = None,
    key: str | None = None,
    load_avg: bool = False,
    args: list[str] | None = None,
    runner: Runner | None = None,
) -> FsTimeOutputs:
    """
    A frontend for the unix /usr/bin/time program to track resource usage by a
    process.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        command: The command to be timed with fs_time.
        output_file: Save resource info into output file.
        key: Specify a key for the resource information.
        load_avg: Report on load averages as from uptime.
        args: Arguments for the command.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsTimeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_TIME_METADATA)
    cargs = []
    cargs.append("fs_time")
    if output_file is not None:
        cargs.extend([
            "-o",
            output_file
        ])
    if key is not None:
        cargs.extend([
            "-k",
            key
        ])
    if load_avg:
        cargs.append("-l")
    cargs.append(command)
    if args is not None:
        cargs.extend(args)
    ret = FsTimeOutputs(
        root=execution.output_file("."),
        resource_output=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_TIME_METADATA",
    "FsTimeOutputs",
    "fs_time",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_TO_SURFACE_3D_DISTANCE_METADATA = Metadata(
    id="3e1ed73b05c8f75edd593f55956978e0e76c8051.boutiques",
    name="surface-to-surface-3d-distance",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceToSurface3dDistanceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_to_surface_3d_distance(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dists_out: OutputPathType
    """the output distances"""
    opt_vectors_vectors_out: OutputPathType | None
    """output the displacement vectors: the output vectors"""


def surface_to_surface_3d_distance(
    surface_comp: InputPathType,
    surface_ref: InputPathType,
    dists_out: str,
    opt_vectors_vectors_out: str | None = None,
    runner: Runner | None = None,
) -> SurfaceToSurface3dDistanceOutputs:
    """
    Compute distance between corresponding vertices.
    
    Computes the vector difference between the vertices of each surface with the
    same index, as (comp - ref), and output the magnitudes, and optionally the
    displacement vectors.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_comp: the surface to compare to the reference.
        surface_ref: the surface to use as the reference.
        dists_out: the output distances.
        opt_vectors_vectors_out: output the displacement vectors: the output\
            vectors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceToSurface3dDistanceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_TO_SURFACE_3D_DISTANCE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-to-surface-3d-distance")
    cargs.append(execution.input_file(surface_comp))
    cargs.append(execution.input_file(surface_ref))
    cargs.append(dists_out)
    if opt_vectors_vectors_out is not None:
        cargs.extend([
            "-vectors",
            opt_vectors_vectors_out
        ])
    ret = SurfaceToSurface3dDistanceOutputs(
        root=execution.output_file("."),
        dists_out=execution.output_file(dists_out),
        opt_vectors_vectors_out=execution.output_file(opt_vectors_vectors_out) if (opt_vectors_vectors_out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_TO_SURFACE_3D_DISTANCE_METADATA",
    "SurfaceToSurface3dDistanceOutputs",
    "surface_to_surface_3d_distance",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HIAM_MAKE_SURFACES_METADATA = Metadata(
    id="eedce2967ed9d851c796ec7ce683d74d056d3684.boutiques",
    name="hiam_make_surfaces",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class HiamMakeSurfacesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `hiam_make_surfaces(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def hiam_make_surfaces(
    subject_name: str,
    structure: typing.Literal["RA", "LA", "RH", "LH"],
    runner: Runner | None = None,
) -> HiamMakeSurfacesOutputs:
    """
    Surface creation tool for specified brain structures.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name for which surfaces are to be created.
        structure: Structure for which surfaces will be created. Valid values\
            are RA, LA, RH, and LH.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `HiamMakeSurfacesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HIAM_MAKE_SURFACES_METADATA)
    cargs = []
    cargs.append("hiam_make_surfaces")
    cargs.append("[OPTIONS]")
    cargs.append(subject_name)
    cargs.append(structure)
    ret = HiamMakeSurfacesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HIAM_MAKE_SURFACES_METADATA",
    "HiamMakeSurfacesOutputs",
    "hiam_make_surfaces",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AUTO_TLRC_METADATA = Metadata(
    id="22feaa9f6bac760643cabb253973d50074192acb.boutiques",
    name="@auto_tlrc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAutoTlrcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__auto_tlrc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType | None
    """Transformed anatomical volume dataset in TLRC space."""
    transform_file: OutputPathType | None
    """Transform used to align the anatomical dataset to the template."""


def v__auto_tlrc(
    base_template: InputPathType,
    input_anat: InputPathType,
    apar: InputPathType,
    input_dataset: InputPathType,
    no_ss: bool = False,
    warp_orig_vol: bool = False,
    dxyz: float | None = None,
    dx: float | None = None,
    dy: float | None = None,
    dz: float | None = None,
    pad_base: float | None = None,
    keep_tmp: bool = False,
    clean: bool = False,
    xform: str | None = None,
    no_avoid_eyes: bool = False,
    ncr: bool = False,
    onepass: bool = False,
    twopass: bool = False,
    maxite: float | None = None,
    not_ok_maxite: bool = False,
    inweight: bool = False,
    rigid_equiv: bool = False,
    init_xform: str | None = None,
    no_pre: bool = False,
    out_space: str | None = None,
    v_3d_allineate: bool = False,
    v_3d_alcost: str | None = None,
    overwrite: bool = False,
    pad_input: float | None = None,
    onewarp: bool = False,
    twowarp: bool = False,
    rmode: str | None = None,
    prefix: str | None = None,
    suffix: str | None = None,
    keep_view: bool = False,
    base_copy: str | None = None,
    base_list: bool = False,
    use_gz: bool = False,
    verb: bool = False,
    runner: Runner | None = None,
) -> VAutoTlrcOutputs:
    """
    A script to transform an anatomical dataset to align with some standard space
    template and to apply the same TLRC transform obtained with @auto_tlrc in Usage
    1 mode to other datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        base_template: Reference anatomical volume. Usually this volume is in\
            some standard space like TLRC or MNI space.
        input_anat: Original anatomical volume (+orig). The skull is removed by\
            this script unless instructed otherwise (-no_ss).
        apar: An anatomical dataset in TLRC space created using Usage 1 of\
            @auto_tlrc.
        input_dataset: Dataset (typically EPI time series or statistical\
            dataset) to transform to TLRC space per the transform in TLRC_parent.
        no_ss: Do not strip skull of input data set because the skull has\
            already been removed or because the template still has the skull.
        warp_orig_vol: Produce a TLRC version of the input volume, rather than\
            a TLRC version of the skull-stripped input.
        dxyz: Cubic voxel size of output DSET in TLRC space. Default is the\
            resolution of the template.
        dx: Size of voxel in the x direction (Right-Left). Default is 1mm.
        dy: Size of voxel in the y direction (Anterior-Posterior). Default is\
            1mm.
        dz: Size of voxel in the z direction (Inferior-Superior). Default is\
            1mm.
        pad_base: Pad the base dataset by MM mm in each direction. Default is\
            15 mm.
        keep_tmp: Keep temporary files.
        clean: Clean all temporary files, likely left from -keep_tmp option\
            then exit.
        xform: Transform to use for warping: Choose from affine_general or\
            shift_rotate_scale. Default is affine_general.
        no_avoid_eyes: An option that gets passed to 3dSkullStrip. Use it when\
            parts of the frontal lobes get clipped.
        ncr: Do not use -coarserot option for 3dWarpDrive, which is a default.
        onepass: Turns off -twopass option for 3dWarpDrive. This will speed up\
            the registration but might fail if the datasets are far apart.
        twopass: Opposite of -onepass, default.
        maxite: Maximum number of iterations for 3dWarpDrive. Default is 50 for\
            first pass and then doubled to 100 in second pass.
        not_ok_maxite: Continue running even if maximum iterations is reached.
        inweight: Apply -weight INPUT (in 3dWarpDrive). By default, 3dWarpDrive\
            uses the BASE dataset to weight the alignment cost.
        rigid_equiv: Output the rigid-body version of the alignment. Resultant\
            volume is NOT in TLRC space.
        init_xform: Apply affine transform in XFORM0.1D before beginning\
            registration and then include XFORM0.1D in the final transform.
        no_pre: Delete temporary dataset created by -init_xform.
        out_space: Set the output to a particular space.
        v_3d_allineate: Use 3dAllineate with the lpa+ZZ cost function instead\
            of 3dWarpDrive.
        v_3d_alcost: Use another cost function like nmi for 3dAllineate.
        overwrite: Overwrite existing output.
        pad_input: Pad the input dataset by MM mm in each direction.
        onewarp: Create follower data with one interpolation step, instead of\
            two. This option reduces blurring of the output data.
        twowarp: Create follower data with two interpolations step, instead of\
            one. This option is for backward compatibility.
        rmode: Resampling mode. Choose from: linear, cubic, NN or quintic.\
            Default for 'Usage 1' is cubic.
        prefix: Name of the output dataset.
        suffix: Name the output dataset by appending this suffix to the prefix\
            of the input data.
        keep_view: Do not mark output dataset as +tlrc.
        base_copy: Copy base (template) dataset into COPY_PREFIX.
        base_list: List the full path of the base dataset.
        use_gz: When using '-suffix ..', behave as if you had provided a prefix\
            with '*.gz' at the end.
        verb: Increase verbosity of the script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAutoTlrcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AUTO_TLRC_METADATA)
    cargs = []
    cargs.append("@auto_tlrc")
    cargs.extend([
        "-base",
        execution.input_file(base_template)
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_anat)
    ])
    if no_ss:
        cargs.append("-no_ss")
    if warp_orig_vol:
        cargs.append("-warp_orig_vol")
    if dxyz is not None:
        cargs.extend([
            "-dxyz",
            str(dxyz)
        ])
    if dx is not None:
        cargs.extend([
            "-dx",
            str(dx)
        ])
    if dy is not None:
        cargs.extend([
            "-dy",
            str(dy)
        ])
    if dz is not None:
        cargs.extend([
            "-dz",
            str(dz)
        ])
    if pad_base is not None:
        cargs.extend([
            "-pad_base",
            str(pad_base)
        ])
    if keep_tmp:
        cargs.append("-keep_tmp")
    if clean:
        cargs.append("-clean")
    if xform is not None:
        cargs.extend([
            "-xform",
            xform
        ])
    if no_avoid_eyes:
        cargs.append("-no_avoid_eyes")
    if ncr:
        cargs.append("-ncr")
    if onepass:
        cargs.append("-onepass")
    if twopass:
        cargs.append("-twopass")
    if maxite is not None:
        cargs.extend([
            "-maxite",
            str(maxite)
        ])
    if not_ok_maxite:
        cargs.append("-not_OK_maxite")
    if inweight:
        cargs.append("-inweight")
    if rigid_equiv:
        cargs.append("-rigid_equiv")
    if init_xform is not None:
        cargs.extend([
            "-init_xform",
            init_xform
        ])
    if no_pre:
        cargs.append("-no_pre")
    if out_space is not None:
        cargs.extend([
            "-out_space",
            out_space
        ])
    if v_3d_allineate:
        cargs.append("-3dAllineate")
    if v_3d_alcost is not None:
        cargs.extend([
            "-3dAlcost",
            v_3d_alcost
        ])
    if overwrite:
        cargs.append("-overwrite")
    cargs.extend([
        "-apar",
        execution.input_file(apar)
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    if pad_input is not None:
        cargs.extend([
            "-pad_input",
            str(pad_input)
        ])
    if onewarp:
        cargs.append("-onewarp")
    if twowarp:
        cargs.append("-twowarp")
    if rmode is not None:
        cargs.extend([
            "-rmode",
            rmode
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if suffix is not None:
        cargs.extend([
            "-suffix",
            suffix
        ])
    if keep_view:
        cargs.append("-keep_view")
    if base_copy is not None:
        cargs.extend([
            "-base_copy",
            base_copy
        ])
    if base_list:
        cargs.append("-base_list")
    if use_gz:
        cargs.append("-use_gz")
    if verb:
        cargs.append("-verb")
    ret = VAutoTlrcOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
        transform_file=execution.output_file(prefix + ".Xat.1D") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAutoTlrcOutputs",
    "V__AUTO_TLRC_METADATA",
    "v__auto_tlrc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DTTO_DWI_METADATA = Metadata(
    id="0f0fbb0dc2b7d522416ef673b66be8d6a5895cef.boutiques",
    name="3dDTtoDWI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDttoDwiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_dtto_dwi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dwi: OutputPathType
    """Computed DWI images including sub-brick for each gradient vector."""


def v_3d_dtto_dwi(
    gradient_file: InputPathType,
    i0_dataset: InputPathType,
    dt_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dDttoDwiOutputs:
    """
    Tool to compute multiple gradient images from tensors and gradient vector
    coordinates applied to the I0-dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        gradient_file: 1D file containing the gradient vectors (ASCII floats)\
            for non-zero gradients.
        i0_dataset: Volume without any gradient applied.
        dt_dataset: 6-sub-brick dataset containing the diffusion tensor data\
            (Dxx, Dxy, Dyy, Dxz, Dyz, Dzz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDttoDwiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DTTO_DWI_METADATA)
    cargs = []
    cargs.append("3dDTtoDWI")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(gradient_file))
    cargs.append(execution.input_file(i0_dataset))
    cargs.append(execution.input_file(dt_dataset))
    ret = V3dDttoDwiOutputs(
        root=execution.output_file("."),
        output_dwi=execution.output_file("[PREFIX]*.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDttoDwiOutputs",
    "V_3D_DTTO_DWI_METADATA",
    "v_3d_dtto_dwi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MM_METADATA = Metadata(
    id="a5f0fd0df34d3464fbfc708013a6765ded373c4d.boutiques",
    name="mm",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mm(
    spatial_data_file: InputPathType,
    mask_file: InputPathType,
    verbose_flag: bool = False,
    debug_level: str | None = None,
    timing_flag: bool = False,
    example_epi_file: InputPathType | None = None,
    log_directory: str | None = None,
    nonspatial_flag: bool = False,
    fix_mrf_precision_flag: bool = False,
    mrf_prec_start: float | None = None,
    mrf_prec_multiplier: float | None = None,
    init_multiplier: float | None = None,
    no_update_theta_flag: bool = False,
    zfstat_flag: bool = False,
    phi: float | None = None,
    niters: float | None = None,
    threshold: float | None = None,
    runner: Runner | None = None,
) -> MmOutputs:
    """
    FSL's MM: mixture modelling.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        spatial_data_file: Spatial map data file.
        mask_file: Mask file.
        verbose_flag: Switch on diagnostic messages.
        debug_level: Set debug level.
        timing_flag: Turn timing on.
        example_epi_file: Example EPI data file.
        log_directory: Log directory.
        nonspatial_flag: Nonspatial mixture model.
        fix_mrf_precision_flag: Fix MRF precision to mrfprecstart throughout.
        mrf_prec_start: MRF precision initial value (default is 10).
        mrf_prec_multiplier: Update multiplier for MRF precision (default is\
            -1, do not multiply).
        init_multiplier: Init multiplier (default is 0.3).
        no_update_theta_flag: Turn off updating of distribution parameters\
            after non-spatial fit.
        zfstat_flag: Turn on zfstat mode - this enforces no deactivation class.
        phi: Phi (default is 0.05).
        niters: Number of iterations (default is -1: auto stop).
        threshold: Threshold for use when displaying classification maps in\
            MM.html report (default is 0.5, -1 indicates no thresholding).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MM_METADATA)
    cargs = []
    cargs.append("mm")
    cargs.extend([
        "--sdf",
        execution.input_file(spatial_data_file)
    ])
    cargs.extend([
        "-m",
        execution.input_file(mask_file)
    ])
    if verbose_flag:
        cargs.append("--verbose")
    if debug_level is not None:
        cargs.extend([
            "--debug",
            debug_level
        ])
    if timing_flag:
        cargs.append("--timingon")
    if example_epi_file is not None:
        cargs.extend([
            "--edf",
            execution.input_file(example_epi_file)
        ])
    if log_directory is not None:
        cargs.extend([
            "--logdir",
            log_directory
        ])
    if nonspatial_flag:
        cargs.append("--ns")
    if fix_mrf_precision_flag:
        cargs.append("--fmp")
    if mrf_prec_start is not None:
        cargs.extend([
            "--mps",
            str(mrf_prec_start)
        ])
    if mrf_prec_multiplier is not None:
        cargs.extend([
            "--mpm",
            str(mrf_prec_multiplier)
        ])
    if init_multiplier is not None:
        cargs.extend([
            "--im",
            str(init_multiplier)
        ])
    if no_update_theta_flag:
        cargs.append("--nut")
    if zfstat_flag:
        cargs.append("--zfstatmode")
    if phi is not None:
        cargs.extend([
            "--phi",
            str(phi)
        ])
    if niters is not None:
        cargs.extend([
            "--ni",
            str(niters)
        ])
    if threshold is not None:
        cargs.extend([
            "--th",
            str(threshold)
        ])
    ret = MmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MM_METADATA",
    "MmOutputs",
    "mm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_MNI305_2MM_METADATA = Metadata(
    id="baca96deead4a89fad3eca8defaa337786ee5cdf.boutiques",
    name="reg-mni305.2mm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RegMni3052mmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_mni305_2mm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_regfile: OutputPathType
    """tkregister2-style registration matrix output file."""


def reg_mni305_2mm(
    subject_id: str,
    regfile: InputPathType,
    runner: Runner | None = None,
) -> RegMni3052mmOutputs:
    """
    Computes the registration between the FreeSurfer MNI305 2mm space and a
    subject's FreeSurfer anatomical space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject ID for the FreeSurfer anatomical space.
        regfile: tkregister2-style registration matrix file (should have a .dat\
            or .reg extension).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegMni3052mmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_MNI305_2MM_METADATA)
    cargs = []
    cargs.append("reg-mni305.2mm")
    cargs.extend([
        "--s",
        subject_id
    ])
    cargs.extend([
        "--reg",
        execution.input_file(regfile)
    ])
    ret = RegMni3052mmOutputs(
        root=execution.output_file("."),
        output_regfile=execution.output_file(pathlib.Path(regfile).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_MNI305_2MM_METADATA",
    "RegMni3052mmOutputs",
    "reg_mni305_2mm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LOMB_SCARGLE_METADATA = Metadata(
    id="ec1cdb90b6faac538a25b9943b1823c8bc7afa27.boutiques",
    name="3dLombScargle",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLombScargleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_lomb_scargle(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    time_points: OutputPathType
    """1D file of the sampled time points (in units of seconds) of the analyzed
    data set"""
    frequency_points: OutputPathType
    """1D file of the frequency sample points (in units of 1/seconds) of the
    output periodogram/spectrum data set"""
    amplitude_spectrum: OutputPathType
    """Volumetric data set containing a LS-derived amplitude spectrum"""
    power_spectrum: OutputPathType
    """Volumetric data set containing a LS-derived power spectrum"""


def v_3d_lomb_scargle(
    prefix: str,
    inset: InputPathType,
    censor_1d: InputPathType | None = None,
    censor_string: str | None = None,
    mask_file: InputPathType | None = None,
    out_pow_spec: bool = False,
    nyquist_multiplier: int | None = None,
    nifti: bool = False,
    runner: Runner | None = None,
) -> V3dLombScargleOutputs:
    """
    Make a periodogram or amplitude-spectrum of a time series that has a
    non-constant sampling rate.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Output prefix name for data volume, time point 1D file, and\
            frequency 1D file.
        inset: Time series of volumes, a 4D volumetric data set.
        censor_1d: Single row or column of 1s (keep) and 0s (censored)\
            describing which volumes of FILE are kept in the sampling and which are\
            censored out, respectively. The length of the list of numbers must be\
            of the same length as the number of volumes in FILE. If not entered,\
            then the program will look for subbricks of all-zeros and assume those\
            are censored out.
        censor_string: AFNI-style selector string of volumes to *keep* in the\
            analysis. Such as: '[0..4,7,10..$]'.
        mask_file: Optional, mask of volume to analyze; additionally, any voxel\
            with uniformly zero values across time will produce a zero-spectrum.
        out_pow_spec: Switch to output the amplitude spectrum of the freqs\
            instead of the periodogram. In the formulation used here, for a time\
            series of length N, the power spectral value S is related to the\
            amplitude value X as: S = (X)**2. (Without this opt, default output is\
            amplitude spectrum.).
        nyquist_multiplier: L-S periodograms can include frequencies above what\
            would typically be considered Nyquist. By default, the maximum\
            frequency will be what f_N *would* have been if no censoring of points\
            had occurred. Acceptable values are >0. (This sets the 'hifac'\
            parameter).
        nifti: Switch to output *.nii.gz volume file (default format is\
            BRIK/HEAD).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLombScargleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LOMB_SCARGLE_METADATA)
    cargs = []
    cargs.append("3dLombScargle")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-inset",
        execution.input_file(inset)
    ])
    if censor_1d is not None:
        cargs.extend([
            "-censor_1D",
            execution.input_file(censor_1d)
        ])
    if censor_string is not None:
        cargs.extend([
            "-censor_str",
            censor_string
        ])
    if mask_file is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_file)
        ])
    if out_pow_spec:
        cargs.append("-out_pow_spec")
    if nyquist_multiplier is not None:
        cargs.extend([
            "-nyq_mult",
            str(nyquist_multiplier)
        ])
    if nifti:
        cargs.append("-nifti")
    ret = V3dLombScargleOutputs(
        root=execution.output_file("."),
        time_points=execution.output_file(prefix + "_time.1D"),
        frequency_points=execution.output_file(prefix + "_freq.1D"),
        amplitude_spectrum=execution.output_file(prefix + "_amp+orig"),
        power_spectrum=execution.output_file(prefix + "_pow+orig"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLombScargleOutputs",
    "V_3D_LOMB_SCARGLE_METADATA",
    "v_3d_lomb_scargle",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MEMA_METADATA = Metadata(
    id="3e49aad2d71d54e4f942b7cc6311a0fe4225ef3f.boutiques",
    name="3dMEMA",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMemaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mema(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file from the analysis"""


def v_3d_mema(
    runner: Runner | None = None,
) -> V3dMemaOutputs:
    """
    3dMEMA is a program for performing Mixed Effects Meta Analysis at group level
    that models both within- and across-subjects variability.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMemaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MEMA_METADATA)
    cargs = []
    cargs.append("3dMEMA")
    cargs.append("[OPTIONS]")
    ret = V3dMemaOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[PREFIX].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMemaOutputs",
    "V_3D_MEMA_METADATA",
    "v_3d_mema",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_AVERAGE_METADATA = Metadata(
    id="e8987396c5ff3a27080f32d2b0e28b39d20a3cb7.boutiques",
    name="cifti-average",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiAverageExcludeOutliers:
    """
    exclude outliers by standard deviation of each element across files.
    """
    sigma_below: float
    """number of standard deviations below the mean to include"""
    sigma_above: float
    """number of standard deviations above the mean to include"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-exclude-outliers")
        cargs.append(str(self.sigma_below))
        cargs.append(str(self.sigma_above))
        return cargs


@dataclasses.dataclass
class CiftiAverageCifti:
    """
    specify an input file.
    """
    cifti_in: InputPathType
    """the input cifti file"""
    opt_weight_weight: float | None = None
    """give a weight for this file: the weight to use"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cifti")
        cargs.append(execution.input_file(self.cifti_in))
        if self.opt_weight_weight is not None:
            cargs.extend([
                "-weight",
                str(self.opt_weight_weight)
            ])
        return cargs


class CiftiAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_average(
    cifti_out: str,
    exclude_outliers: CiftiAverageExcludeOutliers | None = None,
    opt_mem_limit_limit_gb: float | None = None,
    cifti: list[CiftiAverageCifti] | None = None,
    runner: Runner | None = None,
) -> CiftiAverageOutputs:
    """
    Average cifti files.
    
    Averages cifti files together. Files without -weight specified are given a
    weight of 1. If -exclude-outliers is specified, at each element, the data
    across all files is taken as a set, its unweighted mean and sample standard
    deviation are found, and values outside the specified number of standard
    deviations are excluded from the (potentially weighted) average at that
    element.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_out: output cifti file.
        exclude_outliers: exclude outliers by standard deviation of each\
            element across files.
        opt_mem_limit_limit_gb: restrict memory used for file reading\
            efficiency: memory limit in gigabytes.
        cifti: specify an input file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_AVERAGE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-average")
    cargs.append(cifti_out)
    if exclude_outliers is not None:
        cargs.extend(exclude_outliers.run(execution))
    if opt_mem_limit_limit_gb is not None:
        cargs.extend([
            "-mem-limit",
            str(opt_mem_limit_limit_gb)
        ])
    if cifti is not None:
        cargs.extend([a for c in [s.run(execution) for s in cifti] for a in c])
    ret = CiftiAverageOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_AVERAGE_METADATA",
    "CiftiAverageCifti",
    "CiftiAverageExcludeOutliers",
    "CiftiAverageOutputs",
    "cifti_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIXUP_MNI_PATHS_METADATA = Metadata(
    id="2bf5837eea05322482ae33a8bcc9d1f47a565a04.boutiques",
    name="fixup_mni_paths",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FixupMniPathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fixup_mni_paths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    autocrop_backup: OutputPathType
    """Original file backup for autocrop"""
    field2imp_backup: OutputPathType
    """Original file backup for field2imp"""
    imp2field_backup: OutputPathType
    """Original file backup for imp2field"""
    make_template_backup: OutputPathType
    """Original file backup for make_template"""
    mritoself_backup: OutputPathType
    """Original file backup for mritoself"""
    mritotal_backup: OutputPathType
    """Original file backup for mritotal"""
    nu_correct_backup: OutputPathType
    """Original file backup for nu_correct"""
    nu_estimate_backup: OutputPathType
    """Original file backup for nu_estimate"""
    nu_estimate_np_and_em_backup: OutputPathType
    """Original file backup for nu_estimate_np_and_em"""
    nu_evaluate_backup: OutputPathType
    """Original file backup for nu_evaluate"""
    resample_labels_backup: OutputPathType
    """Original file backup for resample_labels"""
    sharpen_volume_backup: OutputPathType
    """Original file backup for sharpen_volume"""
    xfmtool_backup: OutputPathType
    """Original file backup for xfmtool"""


def fixup_mni_paths(
    verbose: bool = False,
    runner: Runner | None = None,
) -> FixupMniPathsOutputs:
    """
    A utility for patching MNI tools to ensure correct paths are used.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        verbose: Provide verbose output during the patch process.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixupMniPathsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIXUP_MNI_PATHS_METADATA)
    cargs = []
    cargs.append("fixup_mni_paths")
    if verbose:
        cargs.append("-v")
    ret = FixupMniPathsOutputs(
        root=execution.output_file("."),
        autocrop_backup=execution.output_file("autocrop.old"),
        field2imp_backup=execution.output_file("field2imp.old"),
        imp2field_backup=execution.output_file("imp2field.old"),
        make_template_backup=execution.output_file("make_template.old"),
        mritoself_backup=execution.output_file("mritoself.old"),
        mritotal_backup=execution.output_file("mritotal.old"),
        nu_correct_backup=execution.output_file("nu_correct.old"),
        nu_estimate_backup=execution.output_file("nu_estimate.old"),
        nu_estimate_np_and_em_backup=execution.output_file("nu_estimate_np_and_em.old"),
        nu_evaluate_backup=execution.output_file("nu_evaluate.old"),
        resample_labels_backup=execution.output_file("resample_labels.old"),
        sharpen_volume_backup=execution.output_file("sharpen_volume.old"),
        xfmtool_backup=execution.output_file("xfmtool.old"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIXUP_MNI_PATHS_METADATA",
    "FixupMniPathsOutputs",
    "fixup_mni_paths",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CBLUMWMGYRI_METADATA = Metadata(
    id="fe20341079c6df1e8a587d62997fab1a4bf8a4d8.boutiques",
    name="cblumwmgyri",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class CblumwmgyriOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cblumwmgyri(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_seg_file: OutputPathType | None
    """Output segmentation file after processing"""


def cblumwmgyri(
    subject: str,
    source_seg: InputPathType | None = None,
    n_erodes_dilates: float | None = 2,
    out_seg: str | None = "sourceseg+cblumwmgyri.mgz",
    no_segstats: bool = False,
    subjects_dir: str | None = None,
    runner: Runner | None = None,
) -> CblumwmgyriOutputs:
    """
    Segments cerebellar white matter into gyral and core components using
    geometrical constraints.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        source_seg: Source segmentation file (default: aparc+aseg.mgz).
        n_erodes_dilates: Number of erosions/dilations (default: 2).
        out_seg: Output segmentation file (default: sourceseg+cblumwmgyri.mgz).
        no_segstats: Do not compute segmentation statistics.
        subjects_dir: Subjects directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CblumwmgyriOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CBLUMWMGYRI_METADATA)
    cargs = []
    cargs.append("cblumwmgyri")
    cargs.extend([
        "--s",
        subject
    ])
    if source_seg is not None:
        cargs.extend([
            "--seg",
            execution.input_file(source_seg)
        ])
    if n_erodes_dilates is not None:
        cargs.extend([
            "--n",
            str(n_erodes_dilates)
        ])
    if out_seg is not None:
        cargs.extend([
            "--o",
            out_seg
        ])
    if no_segstats:
        cargs.append("--no-segstats")
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    ret = CblumwmgyriOutputs(
        root=execution.output_file("."),
        output_seg_file=execution.output_file(out_seg) if (out_seg is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CBLUMWMGYRI_METADATA",
    "CblumwmgyriOutputs",
    "cblumwmgyri",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GIFTI_TOOL_METADATA = Metadata(
    id="4946ede9cc84ec22d01a494ff249ccac8104538c.boutiques",
    name="gifti_tool",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GiftiToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gifti_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_gifti: OutputPathType
    """Output GIFTI file"""


def gifti_tool(
    infile: InputPathType,
    write_gifti: str,
    new_numda: float | None = None,
    new_dtype: str | None = None,
    new_intent: str | None = None,
    new_ndim: float | None = None,
    new_dims: list[float] | None = None,
    set_extern_filelist: list[str] | None = None,
    mod_add_data: bool = False,
    verb: float | None = None,
    show_gifti: bool = False,
    read_das: list[float] | None = None,
    mod_gim_atr: list[str] | None = None,
    mod_gim_meta: list[str] | None = None,
    mod_da_atr: list[str] | None = None,
    mod_da_meta: list[str] | None = None,
    mod_das: list[float] | None = None,
    new_dset: bool = False,
    compare_gifti: bool = False,
    compare_data: bool = False,
    compare_verb: float | None = None,
    approx_gifti: bool = False,
    runner: Runner | None = None,
) -> GiftiToolOutputs:
    """
    Tool for creating, displaying, modifying, or comparing GIFTI datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Specify one or more GIFTI datasets as input.
        write_gifti: Write out dataset as gifti image.
        new_numda: New dataset will have NUMDA DataArray elements.
        new_dtype: Set data type to TYPE.
        new_intent: DA elements will have intent INTENT.
        new_ndim: Set Dimensionality to NUMDIMS.
        new_dims: Set dims[] to these 6 values.
        set_extern_filelist: Store data in external files.
        mod_add_data: Add data to empty DataArray elements.
        verb: Set verbose level.
        show_gifti: Show final gifti image.
        read_das: Read DataArray list indices.
        mod_gim_atr: Set the GIFTI NAME=VALUE attribute pair at GIFTI level.
        mod_gim_meta: Add this pair to the GIFTI MetaData.
        mod_da_atr: Set the DataArray NAME=VALUE attribute pair.
        mod_da_meta: Set the DataArray NAME=VALUE pair in DA's MetaData.
        mod_das: Specify the set of DataArrays to modify.
        new_dset: Create a new GIFTI dataset.
        compare_gifti: Compare two GIFTI datasets.
        compare_data: Flag to request comparison of the data.
        compare_verb: Set the verbose level of comparisons.
        approx_gifti: Approximate comparison of GIFTI datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_TOOL_METADATA)
    cargs = []
    cargs.append("gifti_tool")
    cargs.extend([
        "-infile",
        execution.input_file(infile)
    ])
    if new_numda is not None:
        cargs.extend([
            "-new_numDA",
            str(new_numda)
        ])
    if new_dtype is not None:
        cargs.extend([
            "-new_dtype",
            new_dtype
        ])
    if new_intent is not None:
        cargs.extend([
            "-new_intent",
            new_intent
        ])
    if new_ndim is not None:
        cargs.extend([
            "-new_ndim",
            str(new_ndim)
        ])
    if new_dims is not None:
        cargs.extend([
            "-new_dims",
            *map(str, new_dims)
        ])
    cargs.extend([
        "-write_gifti",
        write_gifti
    ])
    if set_extern_filelist is not None:
        cargs.extend([
            "-set_extern_filelist",
            *set_extern_filelist
        ])
    if mod_add_data:
        cargs.append("-mod_add_data")
    if verb is not None:
        cargs.extend([
            "-verb",
            str(verb)
        ])
    if show_gifti:
        cargs.append("-show_gifti")
    if read_das is not None:
        cargs.extend([
            "-read_DAs",
            *map(str, read_das)
        ])
    if mod_gim_atr is not None:
        cargs.extend([
            "-mod_gim_atr",
            *mod_gim_atr
        ])
    if mod_gim_meta is not None:
        cargs.extend([
            "-mod_gim_meta",
            *mod_gim_meta
        ])
    if mod_da_atr is not None:
        cargs.extend([
            "-mod_DA_atr",
            *mod_da_atr
        ])
    if mod_da_meta is not None:
        cargs.extend([
            "-mod_DA_meta",
            *mod_da_meta
        ])
    if mod_das is not None:
        cargs.extend([
            "-mod_DAs",
            *map(str, mod_das)
        ])
    if new_dset:
        cargs.append("-new_dset")
    if compare_gifti:
        cargs.append("-compare_gifti")
    if compare_data:
        cargs.append("-compare_data")
    if compare_verb is not None:
        cargs.extend([
            "-compare_verb",
            str(compare_verb)
        ])
    if approx_gifti:
        cargs.append("-approx_gifti")
    ret = GiftiToolOutputs(
        root=execution.output_file("."),
        output_gifti=execution.output_file(write_gifti),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GIFTI_TOOL_METADATA",
    "GiftiToolOutputs",
    "gifti_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GRADUNWARP_METADATA = Metadata(
    id="b0cc1536d78ca9cef5fa233e1c04b509599e2a82.boutiques",
    name="mri_gradunwarp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGradunwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gradunwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unwarped_output: OutputPathType | None
    """Unwarped output volume or surface"""
    output_transform_table: OutputPathType | None
    """Saved unwarp transform table in m3z format"""


def mri_gradunwarp(
    input_file: InputPathType,
    gradient_coeff: InputPathType | None = None,
    load_transtbl: InputPathType | None = None,
    output_file: str | None = None,
    out_transtbl: str | None = None,
    save_transtbl_only: bool = False,
    interpolation_type: str | None = "trilinear",
    nthreads: float | None = None,
    checkopts: bool = False,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> MriGradunwarpOutputs:
    """
    Tool to correct gradient non-linearity distortions in MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input warped volume or surface.
        gradient_coeff: Gradient coefficient input file (not to be used with\
            --load_transtbl).
        load_transtbl: Load unwarp transform table in m3z format (not to be\
            used with --gradcoeff).
        output_file: Output unwarped volume or surface.
        out_transtbl: Save unwarp transform table in m3z format.
        save_transtbl_only: Just save unwarp transform table in m3z format,\
            requires --gradcoeff.
        interpolation_type: Interpolation method: nearest | trilinear | cubic\
            (default is trilinear).
        nthreads: Number of threads to run.
        checkopts: Don't run anything, just check options and exit.
        version: Print out version and exit.
        help_: Print out information on how to use this program.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGradunwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GRADUNWARP_METADATA)
    cargs = []
    cargs.append("mri_gradunwarp")
    if gradient_coeff is not None:
        cargs.extend([
            "--gradcoeff",
            execution.input_file(gradient_coeff)
        ])
    if load_transtbl is not None:
        cargs.extend([
            "--load_transtbl",
            execution.input_file(load_transtbl)
        ])
    cargs.extend([
        "--i",
        execution.input_file(input_file)
    ])
    if output_file is not None:
        cargs.extend([
            "--o",
            output_file
        ])
    if out_transtbl is not None:
        cargs.extend([
            "--out_transtbl",
            out_transtbl
        ])
    if save_transtbl_only:
        cargs.append("--save_transtbl_only")
    if interpolation_type is not None:
        cargs.extend([
            "--interp",
            interpolation_type
        ])
    if nthreads is not None:
        cargs.extend([
            "--nthreads",
            str(nthreads)
        ])
    if checkopts:
        cargs.append("--checkopts")
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    ret = MriGradunwarpOutputs(
        root=execution.output_file("."),
        unwarped_output=execution.output_file(output_file) if (output_file is not None) else None,
        output_transform_table=execution.output_file(out_transtbl) if (out_transtbl is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GRADUNWARP_METADATA",
    "MriGradunwarpOutputs",
    "mri_gradunwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSMOOTHFILL_METADATA = Metadata(
    id="decfe9aa72638e1ec65326903fe3b064f1752e01.boutiques",
    name="fslsmoothfill",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslsmoothfillOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslsmoothfill(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslsmoothfill(
    input_image: InputPathType,
    mask_image: InputPathType,
    output_image: str,
    number_of_iterations: int | None = None,
    debug_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> FslsmoothfillOutputs:
    """
    Smoothfill is a tool designed to fill in holes in images by smoothly
    interpolating the pixel values.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_image: Filename of the input image.
        mask_image: Filename of the mask image.
        output_image: Filename for the output smoothed result image.
        number_of_iterations: Number of iterations.
        debug_flag: Turn on debugging output.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslsmoothfillOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSMOOTHFILL_METADATA)
    cargs = []
    cargs.append("fslsmoothfill")
    cargs.append("-i")
    cargs.extend([
        "--in",
        execution.input_file(input_image)
    ])
    cargs.append("-m")
    cargs.extend([
        "--mask",
        execution.input_file(mask_image)
    ])
    cargs.append("-o")
    cargs.extend([
        "--out",
        output_image
    ])
    if number_of_iterations is not None:
        cargs.extend([
            "--niter",
            str(number_of_iterations)
        ])
    if debug_flag:
        cargs.append("--debug")
    if verbose_flag:
        cargs.append("--verbose")
    ret = FslsmoothfillOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSMOOTHFILL_METADATA",
    "FslsmoothfillOutputs",
    "fslsmoothfill",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DSUM_METADATA = Metadata(
    id="bc19d515e82be4f6b3c9c9f81c1a201e83b798ea.boutiques",
    name="1dsum",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dsumOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dsum(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Sum or average of columns in the input files"""


def v_1dsum(
    input_files: list[InputPathType],
    ignore_rows: float | None = None,
    use_rows: float | None = None,
    mean_flag: bool = False,
    nocomment_flag: bool = False,
    okempty_flag: bool = False,
    runner: Runner | None = None,
) -> V1dsumOutputs:
    """
    Sum or average columns of ASCII files with numbers arranged in rows and columns.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input ASCII files with numbers arranged in rows and\
            columns.
        ignore_rows: Skip the first nn rows of each file.
        use_rows: Use only mm rows from each file.
        mean_flag: Compute the average instead of the sum.
        nocomment_flag: Do not reproduce comments from the header of the first\
            input file to the output.
        okempty_flag: If encountering an empty 1D file, print 0 and exit\
            quietly instead of exiting with an error message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dsumOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DSUM_METADATA)
    cargs = []
    cargs.append("1dsum")
    cargs.extend([execution.input_file(f) for f in input_files])
    if ignore_rows is not None:
        cargs.extend([
            "-ignore",
            str(ignore_rows)
        ])
    if use_rows is not None:
        cargs.extend([
            "-use",
            str(use_rows)
        ])
    if mean_flag:
        cargs.append("-mean")
    if nocomment_flag:
        cargs.append("-nocomment")
    if okempty_flag:
        cargs.append("-OKempty")
    ret = V1dsumOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dsumOutputs",
    "V_1DSUM_METADATA",
    "v_1dsum",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DRESAMPLE_METADATA = Metadata(
    id="0d87d38a4f7c77290f6d466ec9698d61440eb3e2.boutiques",
    name="3dresample",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dresampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dresample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""


def v_3dresample(
    in_file: InputPathType,
    prefix: str,
    master: InputPathType | None = None,
    orientation: typing.Literal["AIL", "AIR", "ASL", "ASR", "PIL", "PIR", "PSL", "PSR", "ALI", "ALS", "ARI", "ARS", "PLI", "PLS", "PRI", "PRS", "IAL", "IAR", "IPL", "IPR", "SAL", "SAR", "SPL", "SPR", "ILA", "ILP", "IRA", "IRP", "SLA", "SLP", "SRA", "SRP", "LAI", "LAS", "LPI", "LPS", "RAI", "RAS", "RPI", "RPS", "LIA", "LIP", "LSA", "LSP", "RIA", "RIP", "RSA", "RSP"] | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    resample_mode: typing.Literal["NN", "Li", "Cu", "Bk"] | None = None,
    voxel_size: list[float] | None = None,
    runner: Runner | None = None,
) -> V3dresampleOutputs:
    """
    Resample or reorient an image using AFNI 3dresample command.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: Input file to 3dresample.
        prefix: required prefix for output dataset.
        master: Align dataset grid to a reference file.
        orientation: New orientation code.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        resample_mode: 'nn' or 'li' or 'cu' or 'bk'. Resampling method from set\
            {"nn", "li", "cu", "bk"}. these are for "nearest neighbor", "linear",\
            "cubic" and "blocky"interpolation, respectively. default is nn.
        voxel_size: (a float, a float, a float). Resample to new dx, dy and dz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dresampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DRESAMPLE_METADATA)
    cargs = []
    cargs.append("3dresample")
    cargs.extend([
        "-inset",
        execution.input_file(in_file)
    ])
    if master is not None:
        cargs.extend([
            "-master",
            execution.input_file(master)
        ])
    if orientation is not None:
        cargs.extend([
            "-orient",
            orientation
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if outputtype is not None:
        cargs.append(outputtype)
    if resample_mode is not None:
        cargs.extend([
            "-rmode",
            resample_mode
        ])
    if voxel_size is not None:
        cargs.extend([
            "-dxyz",
            *map(str, voxel_size)
        ])
    ret = V3dresampleOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(prefix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dresampleOutputs",
    "V_3DRESAMPLE_METADATA",
    "v_3dresample",
]
